window.Gleam.initSearch([{"doc":"kitten","title":"kitten","content":"# Kitten\n\n[![Package Version](https://img.shields.io/hexpm/v/net)](https://hex.pm/packages/kitten)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/kitten/)\n\n```sh\ngleam add kitten\n```\n\nKitten is a simple in-browser game engine, based on the HTML canvas element. It uses the model-view-update architecture and provides a handful of utility functions to make game development easier and safer.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/kitten&gt;.\n\nLook at the examples directory on github to learn more.\n\n## Example\n\n```gleam\nimport kitten/canvas\nimport kitten/color\nimport kitten/draw\nimport kitten/key\nimport kitten/vec2.{type Vec2, Vec2}\n\npub fn main() {\n  canvas.start_window(init, update, view, &quot;canvas&quot;, 1920.0, 1080.0, [], [])\n}\n\ntype Model {\n  Model(player_pos: Vec2)\n}\n\nconst player_velocity = 5.0\n\nconst player_size = Vec2(80.0, 80.0)\n\nfn init() {\n  Model(player_pos: Vec2(0.0, 0.0))\n}\n\nfn update(model: Model) {\n  let new_player_pos =\n    model.player_pos\n    |&gt; case key.is_down(key.W) {\n      True -&gt; vec2.add(_, Vec2(0.0, player_velocity))\n      _ -&gt; vec2.id\n    }\n    |&gt; case key.is_down(key.S) {\n      True -&gt; vec2.subtract(_, Vec2(0.0, player_velocity))\n      _ -&gt; vec2.id\n    }\n    |&gt; case key.is_down(key.D) {\n      True -&gt; vec2.add(_, Vec2(player_velocity, 0.0))\n      _ -&gt; vec2.id\n    }\n    |&gt; case key.is_down(key.A) {\n      True -&gt; vec2.subtract(_, Vec2(player_velocity, 0.0))\n      _ -&gt; vec2.id\n    }\n  Model(player_pos: new_player_pos)\n}\n\nfn view(model: Model) {\n  draw.context()\n  |&gt; draw.background(color.black)\n  |&gt; draw.rect(model.player_pos, player_size, color.red)\n  Nil\n}\n```\n\n## Quick start\n\nSince kitten runs in the browser, you will need to compile your game code to javascript and attach it to an HTML file. To start, add `target = &quot;javascript&quot;` to your `gleam.toml` file. Next, create an `index.html` file in your project folder and copy this markdown into it, replacing `demo_proj` and `demo` with the names of your project and main file:\n\n```html\n&lt;!DOCTYPE html&gt;\n&lt;html lang=&quot;en&quot;&gt;\n&lt;head&gt;\n    &lt;meta charset=&quot;UTF-8&quot;&gt;\n    &lt;meta name=&quot;viewport&quot; content=&quot;width=device-width, initial-scale=1.0&quot;&gt;\n&lt;/head&gt;\n&lt;body&gt;\n    &lt;canvas id=&quot;canvas&quot;&gt;&lt;/canvas&gt;\n    &lt;script type=&quot;module&quot;&gt;\n        import { main } from &quot;./build/dev/javascript/demo_proj/demo.mjs&quot;;\n        main();\n    &lt;/script&gt;\n&lt;/body&gt;\n&lt;/html&gt;\n```\n\nNow, just write some gleam code in your main file (I suggest you copy the example from above). Run `gleam build` in the terminal, open the HTML file, and that&#39;s it. You should be able to see a red box on your screen that you can move with the WASD keys.\n\nTo learn more about how the engine works, I suggest you look at the `examples` directory in the Github repo. Make sure to read its README before looking at the example games.\n\n## Further development\n\nThe engine is far from complete at the moment. Particularly on the javascript side, the code is simply a mess of everything that I could get to work from other projects and ChatGPT. I am also not too happy with some of the modules, so expect changes in the near future. \n\nHere are some things that I would like to add to the engine, but so far haven&#39;t figured out how to implement them or how they would fit in: \n- [ ] a more consistent and general `simulate` module with higher-order abstractions and optimisations; possibly a lookahead collision system to prevent glitches\n- [ ] shaders (with WebGL)\n- [ ] effects, like in [Lustre](https://github.com/lustre-labs/lustre), for tasks like communicating with a server; possible even a Lustre integration\n- [ ] better documentation and a partial rewrite of the javascript code\n- [ ] tests \n- [ ] 3D and 3D-ish (eg isometric) support\n\nIf you have ideas on how to make any of this happen, please open a PR or a discussion on Github. All contributions are welcome.\n\n## Credits\n\nThe kitten engine is heavily inspired by the [LittleJS engine](https://github.com/KilledByAPixel/LittleJS) by Frank Force (KilledByAPixel) and borrows many of its features and some of its code from LittleJS.\n\nAs part of the audio system, kitten includes [ZzFX](https://github.com/KilledByAPixel/ZzFX) and [ZzFXM](https://github.com/keithclark/ZzFXM) by Frank Force and Keith Clark. Both sound systems have very useful websites for creating audio: [ZzFX](https://killedbyapixel.github.io/ZzFX/), [ZzFXM](https://keithclark.github.io/ZzFXM/). \n\nThe pre-defined colours in the `color` module are taken directly from [Pico CSS](https://picocss.com/docs/colors). Use their website to browse the colour collection online.\n\nAll of the above are licensed under the MIT license.","url":"index.html"},{"doc":"kitten/canvas","title":"start_embedded","content":"pub fn start_embedded(\n  init init: fn() -&gt; a,\n  update update: fn(a) -&gt; a,\n  view view: fn(a) -&gt; Nil,\n  canvas_id canvas_id: String,\n  canvas_width canvas_width: Float,\n  canvas_height canvas_height: Float,\n  image_sources image_sources: List(String),\n  sound_sources sound_sources: List(String),\n) -&gt; Nil\n Starts the engine on the canvas with the specified id, but does not change its size. The canvas width \n and height must be given in world coordinates. The canvas will automatically be scaled so as to fit the \n world defined by `canvas_width` and `canvas_height`. For the best appearance, the ratio between these needs\n to match the canvas&#39;s aspect ratio.\n \n The canvas must already exist in your HTML file.  Use the `draw` and `sound` modules to access the images \n and sounds from the files specified in `image_sources` and `sound_sources`.\n \n Useful when embedding the game in a static webpage.\nSynonyms:\nkitten/canvas.start_embedded\nkitten/canvas start_embedded","url":"kitten/canvas.html#start_embedded"},{"doc":"kitten/canvas","title":"start_window","content":"pub fn start_window(\n  init init: fn() -&gt; a,\n  update update: fn(a) -&gt; a,\n  view view: fn(a) -&gt; Nil,\n  canvas_id canvas_id: String,\n  canvas_width canvas_width: Float,\n  canvas_height canvas_height: Float,\n  image_sources image_sources: List(String),\n  sound_sources sound_sources: List(String),\n) -&gt; Nil\n Starts the engine on the canvas with the specified id. The canvas width and height must be given in \n world coordinates. The canvas will automatically be stretched to occupy as much of the window as possible\n while preserving the aspect ratio between `canvas_width` and `canvas_height`, and adjusted when the window \n is resized. Note that the margins around the canvas will be coloured when using the `draw.background` \n function. Use CSS if you need to see the real canvas size for debugging:\n \n css\n canvas {\n   border: 1px solid red;\n }\n \n \n The canvas must already exist in your HTML file.  Use the `draw` and `sound` modules to access the images \n and sounds from the files specified in `image_sources` and `sound_sources`.\nSynonyms:\nkitten/canvas.start_window\nkitten/canvas start_window","url":"kitten/canvas.html#start_window"},{"doc":"kitten/canvas","title":"toggle_fullscreen","content":"pub fn toggle_fullscreen(toggle: Bool) -&gt; Nil\n Scales up the canvas to fullscreen mode if `toggle` is set to `True` and exits fullscreen mode \n if `toggle` is set to `False`. Note that due to browser security restrictions, the request to \n enter fullscreen mode must come from a user interaction. Therefore, it cannot be part of the \n `init` function and must be bound to something like a mouse click or a key press. \nSynonyms:\nkitten/canvas.toggle_fullscreen\nkitten/canvas toggle_fullscreen","url":"kitten/canvas.html#toggle_fullscreen"},{"doc":"kitten/canvas","title":"kitten/canvas","content":" This module contains functions for starting the engine, for use within your `main` function.\n You should only ever start the engine once in your code. For most use cases, `start_window`\n should be preferable as it  automatically stretches your canvas to the size of the window and \n updates it when the window is resized.\n \n ### Example:\n \n ```gleam\n pub fn main() {\n   canvas.start_window(init, update, view, &quot;kitten-canvas&quot;, 1920.0, 1080.0, [&quot;kitten.png&quot;, &quot;background.png&quot;], [&quot;theme-song.js&quot;])\n }\n ```","url":"kitten/canvas.html"},{"doc":"kitten/color","title":"Color","content":"pub opaque type Color\n\n\nSynonyms:\nkitten/color.Color\nkitten/color Color","url":"kitten/color.html#Color"},{"doc":"kitten/color","title":"amber","content":"pub const amber: Color\n\nSynonyms:\nkitten/color.amber\nkitten/color amber","url":"kitten/color.html#amber"},{"doc":"kitten/color","title":"amber_050","content":"pub const amber_050: Color\n\nSynonyms:\nkitten/color.amber_050\nkitten/color amber_050","url":"kitten/color.html#amber_050"},{"doc":"kitten/color","title":"amber_100","content":"pub const amber_100: Color\n\nSynonyms:\nkitten/color.amber_100\nkitten/color amber_100","url":"kitten/color.html#amber_100"},{"doc":"kitten/color","title":"amber_150","content":"pub const amber_150: Color\n\nSynonyms:\nkitten/color.amber_150\nkitten/color amber_150","url":"kitten/color.html#amber_150"},{"doc":"kitten/color","title":"amber_200","content":"pub const amber_200: Color\n\nSynonyms:\nkitten/color.amber_200\nkitten/color amber_200","url":"kitten/color.html#amber_200"},{"doc":"kitten/color","title":"amber_250","content":"pub const amber_250: Color\n\nSynonyms:\nkitten/color.amber_250\nkitten/color amber_250","url":"kitten/color.html#amber_250"},{"doc":"kitten/color","title":"amber_300","content":"pub const amber_300: Color\n\nSynonyms:\nkitten/color.amber_300\nkitten/color amber_300","url":"kitten/color.html#amber_300"},{"doc":"kitten/color","title":"amber_350","content":"pub const amber_350: Color\n\nSynonyms:\nkitten/color.amber_350\nkitten/color amber_350","url":"kitten/color.html#amber_350"},{"doc":"kitten/color","title":"amber_400","content":"pub const amber_400: Color\n\nSynonyms:\nkitten/color.amber_400\nkitten/color amber_400","url":"kitten/color.html#amber_400"},{"doc":"kitten/color","title":"amber_450","content":"pub const amber_450: Color\n\nSynonyms:\nkitten/color.amber_450\nkitten/color amber_450","url":"kitten/color.html#amber_450"},{"doc":"kitten/color","title":"amber_500","content":"pub const amber_500: Color\n\nSynonyms:\nkitten/color.amber_500\nkitten/color amber_500","url":"kitten/color.html#amber_500"},{"doc":"kitten/color","title":"amber_550","content":"pub const amber_550: Color\n\nSynonyms:\nkitten/color.amber_550\nkitten/color amber_550","url":"kitten/color.html#amber_550"},{"doc":"kitten/color","title":"amber_600","content":"pub const amber_600: Color\n\nSynonyms:\nkitten/color.amber_600\nkitten/color amber_600","url":"kitten/color.html#amber_600"},{"doc":"kitten/color","title":"amber_650","content":"pub const amber_650: Color\n\nSynonyms:\nkitten/color.amber_650\nkitten/color amber_650","url":"kitten/color.html#amber_650"},{"doc":"kitten/color","title":"amber_700","content":"pub const amber_700: Color\n\nSynonyms:\nkitten/color.amber_700\nkitten/color amber_700","url":"kitten/color.html#amber_700"},{"doc":"kitten/color","title":"amber_750","content":"pub const amber_750: Color\n\nSynonyms:\nkitten/color.amber_750\nkitten/color amber_750","url":"kitten/color.html#amber_750"},{"doc":"kitten/color","title":"amber_800","content":"pub const amber_800: Color\n\nSynonyms:\nkitten/color.amber_800\nkitten/color amber_800","url":"kitten/color.html#amber_800"},{"doc":"kitten/color","title":"amber_850","content":"pub const amber_850: Color\n\nSynonyms:\nkitten/color.amber_850\nkitten/color amber_850","url":"kitten/color.html#amber_850"},{"doc":"kitten/color","title":"amber_900","content":"pub const amber_900: Color\n\nSynonyms:\nkitten/color.amber_900\nkitten/color amber_900","url":"kitten/color.html#amber_900"},{"doc":"kitten/color","title":"amber_950","content":"pub const amber_950: Color\n\nSynonyms:\nkitten/color.amber_950\nkitten/color amber_950","url":"kitten/color.html#amber_950"},{"doc":"kitten/color","title":"azure","content":"pub const azure: Color\n\nSynonyms:\nkitten/color.azure\nkitten/color azure","url":"kitten/color.html#azure"},{"doc":"kitten/color","title":"azure_050","content":"pub const azure_050: Color\n\nSynonyms:\nkitten/color.azure_050\nkitten/color azure_050","url":"kitten/color.html#azure_050"},{"doc":"kitten/color","title":"azure_100","content":"pub const azure_100: Color\n\nSynonyms:\nkitten/color.azure_100\nkitten/color azure_100","url":"kitten/color.html#azure_100"},{"doc":"kitten/color","title":"azure_150","content":"pub const azure_150: Color\n\nSynonyms:\nkitten/color.azure_150\nkitten/color azure_150","url":"kitten/color.html#azure_150"},{"doc":"kitten/color","title":"azure_200","content":"pub const azure_200: Color\n\nSynonyms:\nkitten/color.azure_200\nkitten/color azure_200","url":"kitten/color.html#azure_200"},{"doc":"kitten/color","title":"azure_250","content":"pub const azure_250: Color\n\nSynonyms:\nkitten/color.azure_250\nkitten/color azure_250","url":"kitten/color.html#azure_250"},{"doc":"kitten/color","title":"azure_300","content":"pub const azure_300: Color\n\nSynonyms:\nkitten/color.azure_300\nkitten/color azure_300","url":"kitten/color.html#azure_300"},{"doc":"kitten/color","title":"azure_350","content":"pub const azure_350: Color\n\nSynonyms:\nkitten/color.azure_350\nkitten/color azure_350","url":"kitten/color.html#azure_350"},{"doc":"kitten/color","title":"azure_400","content":"pub const azure_400: Color\n\nSynonyms:\nkitten/color.azure_400\nkitten/color azure_400","url":"kitten/color.html#azure_400"},{"doc":"kitten/color","title":"azure_450","content":"pub const azure_450: Color\n\nSynonyms:\nkitten/color.azure_450\nkitten/color azure_450","url":"kitten/color.html#azure_450"},{"doc":"kitten/color","title":"azure_500","content":"pub const azure_500: Color\n\nSynonyms:\nkitten/color.azure_500\nkitten/color azure_500","url":"kitten/color.html#azure_500"},{"doc":"kitten/color","title":"azure_550","content":"pub const azure_550: Color\n\nSynonyms:\nkitten/color.azure_550\nkitten/color azure_550","url":"kitten/color.html#azure_550"},{"doc":"kitten/color","title":"azure_600","content":"pub const azure_600: Color\n\nSynonyms:\nkitten/color.azure_600\nkitten/color azure_600","url":"kitten/color.html#azure_600"},{"doc":"kitten/color","title":"azure_650","content":"pub const azure_650: Color\n\nSynonyms:\nkitten/color.azure_650\nkitten/color azure_650","url":"kitten/color.html#azure_650"},{"doc":"kitten/color","title":"azure_700","content":"pub const azure_700: Color\n\nSynonyms:\nkitten/color.azure_700\nkitten/color azure_700","url":"kitten/color.html#azure_700"},{"doc":"kitten/color","title":"azure_750","content":"pub const azure_750: Color\n\nSynonyms:\nkitten/color.azure_750\nkitten/color azure_750","url":"kitten/color.html#azure_750"},{"doc":"kitten/color","title":"azure_800","content":"pub const azure_800: Color\n\nSynonyms:\nkitten/color.azure_800\nkitten/color azure_800","url":"kitten/color.html#azure_800"},{"doc":"kitten/color","title":"azure_850","content":"pub const azure_850: Color\n\nSynonyms:\nkitten/color.azure_850\nkitten/color azure_850","url":"kitten/color.html#azure_850"},{"doc":"kitten/color","title":"azure_900","content":"pub const azure_900: Color\n\nSynonyms:\nkitten/color.azure_900\nkitten/color azure_900","url":"kitten/color.html#azure_900"},{"doc":"kitten/color","title":"azure_950","content":"pub const azure_950: Color\n\nSynonyms:\nkitten/color.azure_950\nkitten/color azure_950","url":"kitten/color.html#azure_950"},{"doc":"kitten/color","title":"black","content":"pub const black: Color\n\nSynonyms:\nkitten/color.black\nkitten/color black","url":"kitten/color.html#black"},{"doc":"kitten/color","title":"blue","content":"pub const blue: Color\n\nSynonyms:\nkitten/color.blue\nkitten/color blue","url":"kitten/color.html#blue"},{"doc":"kitten/color","title":"blue_050","content":"pub const blue_050: Color\n\nSynonyms:\nkitten/color.blue_050\nkitten/color blue_050","url":"kitten/color.html#blue_050"},{"doc":"kitten/color","title":"blue_100","content":"pub const blue_100: Color\n\nSynonyms:\nkitten/color.blue_100\nkitten/color blue_100","url":"kitten/color.html#blue_100"},{"doc":"kitten/color","title":"blue_150","content":"pub const blue_150: Color\n\nSynonyms:\nkitten/color.blue_150\nkitten/color blue_150","url":"kitten/color.html#blue_150"},{"doc":"kitten/color","title":"blue_200","content":"pub const blue_200: Color\n\nSynonyms:\nkitten/color.blue_200\nkitten/color blue_200","url":"kitten/color.html#blue_200"},{"doc":"kitten/color","title":"blue_250","content":"pub const blue_250: Color\n\nSynonyms:\nkitten/color.blue_250\nkitten/color blue_250","url":"kitten/color.html#blue_250"},{"doc":"kitten/color","title":"blue_300","content":"pub const blue_300: Color\n\nSynonyms:\nkitten/color.blue_300\nkitten/color blue_300","url":"kitten/color.html#blue_300"},{"doc":"kitten/color","title":"blue_350","content":"pub const blue_350: Color\n\nSynonyms:\nkitten/color.blue_350\nkitten/color blue_350","url":"kitten/color.html#blue_350"},{"doc":"kitten/color","title":"blue_400","content":"pub const blue_400: Color\n\nSynonyms:\nkitten/color.blue_400\nkitten/color blue_400","url":"kitten/color.html#blue_400"},{"doc":"kitten/color","title":"blue_450","content":"pub const blue_450: Color\n\nSynonyms:\nkitten/color.blue_450\nkitten/color blue_450","url":"kitten/color.html#blue_450"},{"doc":"kitten/color","title":"blue_500","content":"pub const blue_500: Color\n\nSynonyms:\nkitten/color.blue_500\nkitten/color blue_500","url":"kitten/color.html#blue_500"},{"doc":"kitten/color","title":"blue_550","content":"pub const blue_550: Color\n\nSynonyms:\nkitten/color.blue_550\nkitten/color blue_550","url":"kitten/color.html#blue_550"},{"doc":"kitten/color","title":"blue_600","content":"pub const blue_600: Color\n\nSynonyms:\nkitten/color.blue_600\nkitten/color blue_600","url":"kitten/color.html#blue_600"},{"doc":"kitten/color","title":"blue_650","content":"pub const blue_650: Color\n\nSynonyms:\nkitten/color.blue_650\nkitten/color blue_650","url":"kitten/color.html#blue_650"},{"doc":"kitten/color","title":"blue_700","content":"pub const blue_700: Color\n\nSynonyms:\nkitten/color.blue_700\nkitten/color blue_700","url":"kitten/color.html#blue_700"},{"doc":"kitten/color","title":"blue_750","content":"pub const blue_750: Color\n\nSynonyms:\nkitten/color.blue_750\nkitten/color blue_750","url":"kitten/color.html#blue_750"},{"doc":"kitten/color","title":"blue_800","content":"pub const blue_800: Color\n\nSynonyms:\nkitten/color.blue_800\nkitten/color blue_800","url":"kitten/color.html#blue_800"},{"doc":"kitten/color","title":"blue_850","content":"pub const blue_850: Color\n\nSynonyms:\nkitten/color.blue_850\nkitten/color blue_850","url":"kitten/color.html#blue_850"},{"doc":"kitten/color","title":"blue_900","content":"pub const blue_900: Color\n\nSynonyms:\nkitten/color.blue_900\nkitten/color blue_900","url":"kitten/color.html#blue_900"},{"doc":"kitten/color","title":"blue_950","content":"pub const blue_950: Color\n\nSynonyms:\nkitten/color.blue_950\nkitten/color blue_950","url":"kitten/color.html#blue_950"},{"doc":"kitten/color","title":"cyan","content":"pub const cyan: Color\n\nSynonyms:\nkitten/color.cyan\nkitten/color cyan","url":"kitten/color.html#cyan"},{"doc":"kitten/color","title":"cyan_050","content":"pub const cyan_050: Color\n\nSynonyms:\nkitten/color.cyan_050\nkitten/color cyan_050","url":"kitten/color.html#cyan_050"},{"doc":"kitten/color","title":"cyan_100","content":"pub const cyan_100: Color\n\nSynonyms:\nkitten/color.cyan_100\nkitten/color cyan_100","url":"kitten/color.html#cyan_100"},{"doc":"kitten/color","title":"cyan_150","content":"pub const cyan_150: Color\n\nSynonyms:\nkitten/color.cyan_150\nkitten/color cyan_150","url":"kitten/color.html#cyan_150"},{"doc":"kitten/color","title":"cyan_200","content":"pub const cyan_200: Color\n\nSynonyms:\nkitten/color.cyan_200\nkitten/color cyan_200","url":"kitten/color.html#cyan_200"},{"doc":"kitten/color","title":"cyan_250","content":"pub const cyan_250: Color\n\nSynonyms:\nkitten/color.cyan_250\nkitten/color cyan_250","url":"kitten/color.html#cyan_250"},{"doc":"kitten/color","title":"cyan_300","content":"pub const cyan_300: Color\n\nSynonyms:\nkitten/color.cyan_300\nkitten/color cyan_300","url":"kitten/color.html#cyan_300"},{"doc":"kitten/color","title":"cyan_350","content":"pub const cyan_350: Color\n\nSynonyms:\nkitten/color.cyan_350\nkitten/color cyan_350","url":"kitten/color.html#cyan_350"},{"doc":"kitten/color","title":"cyan_400","content":"pub const cyan_400: Color\n\nSynonyms:\nkitten/color.cyan_400\nkitten/color cyan_400","url":"kitten/color.html#cyan_400"},{"doc":"kitten/color","title":"cyan_450","content":"pub const cyan_450: Color\n\nSynonyms:\nkitten/color.cyan_450\nkitten/color cyan_450","url":"kitten/color.html#cyan_450"},{"doc":"kitten/color","title":"cyan_500","content":"pub const cyan_500: Color\n\nSynonyms:\nkitten/color.cyan_500\nkitten/color cyan_500","url":"kitten/color.html#cyan_500"},{"doc":"kitten/color","title":"cyan_550","content":"pub const cyan_550: Color\n\nSynonyms:\nkitten/color.cyan_550\nkitten/color cyan_550","url":"kitten/color.html#cyan_550"},{"doc":"kitten/color","title":"cyan_600","content":"pub const cyan_600: Color\n\nSynonyms:\nkitten/color.cyan_600\nkitten/color cyan_600","url":"kitten/color.html#cyan_600"},{"doc":"kitten/color","title":"cyan_650","content":"pub const cyan_650: Color\n\nSynonyms:\nkitten/color.cyan_650\nkitten/color cyan_650","url":"kitten/color.html#cyan_650"},{"doc":"kitten/color","title":"cyan_700","content":"pub const cyan_700: Color\n\nSynonyms:\nkitten/color.cyan_700\nkitten/color cyan_700","url":"kitten/color.html#cyan_700"},{"doc":"kitten/color","title":"cyan_750","content":"pub const cyan_750: Color\n\nSynonyms:\nkitten/color.cyan_750\nkitten/color cyan_750","url":"kitten/color.html#cyan_750"},{"doc":"kitten/color","title":"cyan_800","content":"pub const cyan_800: Color\n\nSynonyms:\nkitten/color.cyan_800\nkitten/color cyan_800","url":"kitten/color.html#cyan_800"},{"doc":"kitten/color","title":"cyan_850","content":"pub const cyan_850: Color\n\nSynonyms:\nkitten/color.cyan_850\nkitten/color cyan_850","url":"kitten/color.html#cyan_850"},{"doc":"kitten/color","title":"cyan_900","content":"pub const cyan_900: Color\n\nSynonyms:\nkitten/color.cyan_900\nkitten/color cyan_900","url":"kitten/color.html#cyan_900"},{"doc":"kitten/color","title":"cyan_950","content":"pub const cyan_950: Color\n\nSynonyms:\nkitten/color.cyan_950\nkitten/color cyan_950","url":"kitten/color.html#cyan_950"},{"doc":"kitten/color","title":"fuchsia","content":"pub const fuchsia: Color\n\nSynonyms:\nkitten/color.fuchsia\nkitten/color fuchsia","url":"kitten/color.html#fuchsia"},{"doc":"kitten/color","title":"fuchsia_050","content":"pub const fuchsia_050: Color\n\nSynonyms:\nkitten/color.fuchsia_050\nkitten/color fuchsia_050","url":"kitten/color.html#fuchsia_050"},{"doc":"kitten/color","title":"fuchsia_100","content":"pub const fuchsia_100: Color\n\nSynonyms:\nkitten/color.fuchsia_100\nkitten/color fuchsia_100","url":"kitten/color.html#fuchsia_100"},{"doc":"kitten/color","title":"fuchsia_150","content":"pub const fuchsia_150: Color\n\nSynonyms:\nkitten/color.fuchsia_150\nkitten/color fuchsia_150","url":"kitten/color.html#fuchsia_150"},{"doc":"kitten/color","title":"fuchsia_200","content":"pub const fuchsia_200: Color\n\nSynonyms:\nkitten/color.fuchsia_200\nkitten/color fuchsia_200","url":"kitten/color.html#fuchsia_200"},{"doc":"kitten/color","title":"fuchsia_250","content":"pub const fuchsia_250: Color\n\nSynonyms:\nkitten/color.fuchsia_250\nkitten/color fuchsia_250","url":"kitten/color.html#fuchsia_250"},{"doc":"kitten/color","title":"fuchsia_300","content":"pub const fuchsia_300: Color\n\nSynonyms:\nkitten/color.fuchsia_300\nkitten/color fuchsia_300","url":"kitten/color.html#fuchsia_300"},{"doc":"kitten/color","title":"fuchsia_350","content":"pub const fuchsia_350: Color\n\nSynonyms:\nkitten/color.fuchsia_350\nkitten/color fuchsia_350","url":"kitten/color.html#fuchsia_350"},{"doc":"kitten/color","title":"fuchsia_400","content":"pub const fuchsia_400: Color\n\nSynonyms:\nkitten/color.fuchsia_400\nkitten/color fuchsia_400","url":"kitten/color.html#fuchsia_400"},{"doc":"kitten/color","title":"fuchsia_450","content":"pub const fuchsia_450: Color\n\nSynonyms:\nkitten/color.fuchsia_450\nkitten/color fuchsia_450","url":"kitten/color.html#fuchsia_450"},{"doc":"kitten/color","title":"fuchsia_500","content":"pub const fuchsia_500: Color\n\nSynonyms:\nkitten/color.fuchsia_500\nkitten/color fuchsia_500","url":"kitten/color.html#fuchsia_500"},{"doc":"kitten/color","title":"fuchsia_550","content":"pub const fuchsia_550: Color\n\nSynonyms:\nkitten/color.fuchsia_550\nkitten/color fuchsia_550","url":"kitten/color.html#fuchsia_550"},{"doc":"kitten/color","title":"fuchsia_600","content":"pub const fuchsia_600: Color\n\nSynonyms:\nkitten/color.fuchsia_600\nkitten/color fuchsia_600","url":"kitten/color.html#fuchsia_600"},{"doc":"kitten/color","title":"fuchsia_650","content":"pub const fuchsia_650: Color\n\nSynonyms:\nkitten/color.fuchsia_650\nkitten/color fuchsia_650","url":"kitten/color.html#fuchsia_650"},{"doc":"kitten/color","title":"fuchsia_700","content":"pub const fuchsia_700: Color\n\nSynonyms:\nkitten/color.fuchsia_700\nkitten/color fuchsia_700","url":"kitten/color.html#fuchsia_700"},{"doc":"kitten/color","title":"fuchsia_750","content":"pub const fuchsia_750: Color\n\nSynonyms:\nkitten/color.fuchsia_750\nkitten/color fuchsia_750","url":"kitten/color.html#fuchsia_750"},{"doc":"kitten/color","title":"fuchsia_800","content":"pub const fuchsia_800: Color\n\nSynonyms:\nkitten/color.fuchsia_800\nkitten/color fuchsia_800","url":"kitten/color.html#fuchsia_800"},{"doc":"kitten/color","title":"fuchsia_850","content":"pub const fuchsia_850: Color\n\nSynonyms:\nkitten/color.fuchsia_850\nkitten/color fuchsia_850","url":"kitten/color.html#fuchsia_850"},{"doc":"kitten/color","title":"fuchsia_900","content":"pub const fuchsia_900: Color\n\nSynonyms:\nkitten/color.fuchsia_900\nkitten/color fuchsia_900","url":"kitten/color.html#fuchsia_900"},{"doc":"kitten/color","title":"fuchsia_950","content":"pub const fuchsia_950: Color\n\nSynonyms:\nkitten/color.fuchsia_950\nkitten/color fuchsia_950","url":"kitten/color.html#fuchsia_950"},{"doc":"kitten/color","title":"green","content":"pub const green: Color\n\nSynonyms:\nkitten/color.green\nkitten/color green","url":"kitten/color.html#green"},{"doc":"kitten/color","title":"green_050","content":"pub const green_050: Color\n\nSynonyms:\nkitten/color.green_050\nkitten/color green_050","url":"kitten/color.html#green_050"},{"doc":"kitten/color","title":"green_100","content":"pub const green_100: Color\n\nSynonyms:\nkitten/color.green_100\nkitten/color green_100","url":"kitten/color.html#green_100"},{"doc":"kitten/color","title":"green_150","content":"pub const green_150: Color\n\nSynonyms:\nkitten/color.green_150\nkitten/color green_150","url":"kitten/color.html#green_150"},{"doc":"kitten/color","title":"green_200","content":"pub const green_200: Color\n\nSynonyms:\nkitten/color.green_200\nkitten/color green_200","url":"kitten/color.html#green_200"},{"doc":"kitten/color","title":"green_250","content":"pub const green_250: Color\n\nSynonyms:\nkitten/color.green_250\nkitten/color green_250","url":"kitten/color.html#green_250"},{"doc":"kitten/color","title":"green_300","content":"pub const green_300: Color\n\nSynonyms:\nkitten/color.green_300\nkitten/color green_300","url":"kitten/color.html#green_300"},{"doc":"kitten/color","title":"green_350","content":"pub const green_350: Color\n\nSynonyms:\nkitten/color.green_350\nkitten/color green_350","url":"kitten/color.html#green_350"},{"doc":"kitten/color","title":"green_400","content":"pub const green_400: Color\n\nSynonyms:\nkitten/color.green_400\nkitten/color green_400","url":"kitten/color.html#green_400"},{"doc":"kitten/color","title":"green_450","content":"pub const green_450: Color\n\nSynonyms:\nkitten/color.green_450\nkitten/color green_450","url":"kitten/color.html#green_450"},{"doc":"kitten/color","title":"green_500","content":"pub const green_500: Color\n\nSynonyms:\nkitten/color.green_500\nkitten/color green_500","url":"kitten/color.html#green_500"},{"doc":"kitten/color","title":"green_550","content":"pub const green_550: Color\n\nSynonyms:\nkitten/color.green_550\nkitten/color green_550","url":"kitten/color.html#green_550"},{"doc":"kitten/color","title":"green_600","content":"pub const green_600: Color\n\nSynonyms:\nkitten/color.green_600\nkitten/color green_600","url":"kitten/color.html#green_600"},{"doc":"kitten/color","title":"green_650","content":"pub const green_650: Color\n\nSynonyms:\nkitten/color.green_650\nkitten/color green_650","url":"kitten/color.html#green_650"},{"doc":"kitten/color","title":"green_700","content":"pub const green_700: Color\n\nSynonyms:\nkitten/color.green_700\nkitten/color green_700","url":"kitten/color.html#green_700"},{"doc":"kitten/color","title":"green_750","content":"pub const green_750: Color\n\nSynonyms:\nkitten/color.green_750\nkitten/color green_750","url":"kitten/color.html#green_750"},{"doc":"kitten/color","title":"green_800","content":"pub const green_800: Color\n\nSynonyms:\nkitten/color.green_800\nkitten/color green_800","url":"kitten/color.html#green_800"},{"doc":"kitten/color","title":"green_850","content":"pub const green_850: Color\n\nSynonyms:\nkitten/color.green_850\nkitten/color green_850","url":"kitten/color.html#green_850"},{"doc":"kitten/color","title":"green_900","content":"pub const green_900: Color\n\nSynonyms:\nkitten/color.green_900\nkitten/color green_900","url":"kitten/color.html#green_900"},{"doc":"kitten/color","title":"green_950","content":"pub const green_950: Color\n\nSynonyms:\nkitten/color.green_950\nkitten/color green_950","url":"kitten/color.html#green_950"},{"doc":"kitten/color","title":"grey","content":"pub const grey: Color\n\nSynonyms:\nkitten/color.grey\nkitten/color grey","url":"kitten/color.html#grey"},{"doc":"kitten/color","title":"grey_050","content":"pub const grey_050: Color\n\nSynonyms:\nkitten/color.grey_050\nkitten/color grey_050","url":"kitten/color.html#grey_050"},{"doc":"kitten/color","title":"grey_100","content":"pub const grey_100: Color\n\nSynonyms:\nkitten/color.grey_100\nkitten/color grey_100","url":"kitten/color.html#grey_100"},{"doc":"kitten/color","title":"grey_150","content":"pub const grey_150: Color\n\nSynonyms:\nkitten/color.grey_150\nkitten/color grey_150","url":"kitten/color.html#grey_150"},{"doc":"kitten/color","title":"grey_200","content":"pub const grey_200: Color\n\nSynonyms:\nkitten/color.grey_200\nkitten/color grey_200","url":"kitten/color.html#grey_200"},{"doc":"kitten/color","title":"grey_250","content":"pub const grey_250: Color\n\nSynonyms:\nkitten/color.grey_250\nkitten/color grey_250","url":"kitten/color.html#grey_250"},{"doc":"kitten/color","title":"grey_300","content":"pub const grey_300: Color\n\nSynonyms:\nkitten/color.grey_300\nkitten/color grey_300","url":"kitten/color.html#grey_300"},{"doc":"kitten/color","title":"grey_350","content":"pub const grey_350: Color\n\nSynonyms:\nkitten/color.grey_350\nkitten/color grey_350","url":"kitten/color.html#grey_350"},{"doc":"kitten/color","title":"grey_400","content":"pub const grey_400: Color\n\nSynonyms:\nkitten/color.grey_400\nkitten/color grey_400","url":"kitten/color.html#grey_400"},{"doc":"kitten/color","title":"grey_450","content":"pub const grey_450: Color\n\nSynonyms:\nkitten/color.grey_450\nkitten/color grey_450","url":"kitten/color.html#grey_450"},{"doc":"kitten/color","title":"grey_500","content":"pub const grey_500: Color\n\nSynonyms:\nkitten/color.grey_500\nkitten/color grey_500","url":"kitten/color.html#grey_500"},{"doc":"kitten/color","title":"grey_550","content":"pub const grey_550: Color\n\nSynonyms:\nkitten/color.grey_550\nkitten/color grey_550","url":"kitten/color.html#grey_550"},{"doc":"kitten/color","title":"grey_600","content":"pub const grey_600: Color\n\nSynonyms:\nkitten/color.grey_600\nkitten/color grey_600","url":"kitten/color.html#grey_600"},{"doc":"kitten/color","title":"grey_650","content":"pub const grey_650: Color\n\nSynonyms:\nkitten/color.grey_650\nkitten/color grey_650","url":"kitten/color.html#grey_650"},{"doc":"kitten/color","title":"grey_700","content":"pub const grey_700: Color\n\nSynonyms:\nkitten/color.grey_700\nkitten/color grey_700","url":"kitten/color.html#grey_700"},{"doc":"kitten/color","title":"grey_750","content":"pub const grey_750: Color\n\nSynonyms:\nkitten/color.grey_750\nkitten/color grey_750","url":"kitten/color.html#grey_750"},{"doc":"kitten/color","title":"grey_800","content":"pub const grey_800: Color\n\nSynonyms:\nkitten/color.grey_800\nkitten/color grey_800","url":"kitten/color.html#grey_800"},{"doc":"kitten/color","title":"grey_850","content":"pub const grey_850: Color\n\nSynonyms:\nkitten/color.grey_850\nkitten/color grey_850","url":"kitten/color.html#grey_850"},{"doc":"kitten/color","title":"grey_900","content":"pub const grey_900: Color\n\nSynonyms:\nkitten/color.grey_900\nkitten/color grey_900","url":"kitten/color.html#grey_900"},{"doc":"kitten/color","title":"grey_950","content":"pub const grey_950: Color\n\nSynonyms:\nkitten/color.grey_950\nkitten/color grey_950","url":"kitten/color.html#grey_950"},{"doc":"kitten/color","title":"indigo","content":"pub const indigo: Color\n\nSynonyms:\nkitten/color.indigo\nkitten/color indigo","url":"kitten/color.html#indigo"},{"doc":"kitten/color","title":"indigo_050","content":"pub const indigo_050: Color\n\nSynonyms:\nkitten/color.indigo_050\nkitten/color indigo_050","url":"kitten/color.html#indigo_050"},{"doc":"kitten/color","title":"indigo_100","content":"pub const indigo_100: Color\n\nSynonyms:\nkitten/color.indigo_100\nkitten/color indigo_100","url":"kitten/color.html#indigo_100"},{"doc":"kitten/color","title":"indigo_150","content":"pub const indigo_150: Color\n\nSynonyms:\nkitten/color.indigo_150\nkitten/color indigo_150","url":"kitten/color.html#indigo_150"},{"doc":"kitten/color","title":"indigo_200","content":"pub const indigo_200: Color\n\nSynonyms:\nkitten/color.indigo_200\nkitten/color indigo_200","url":"kitten/color.html#indigo_200"},{"doc":"kitten/color","title":"indigo_250","content":"pub const indigo_250: Color\n\nSynonyms:\nkitten/color.indigo_250\nkitten/color indigo_250","url":"kitten/color.html#indigo_250"},{"doc":"kitten/color","title":"indigo_300","content":"pub const indigo_300: Color\n\nSynonyms:\nkitten/color.indigo_300\nkitten/color indigo_300","url":"kitten/color.html#indigo_300"},{"doc":"kitten/color","title":"indigo_350","content":"pub const indigo_350: Color\n\nSynonyms:\nkitten/color.indigo_350\nkitten/color indigo_350","url":"kitten/color.html#indigo_350"},{"doc":"kitten/color","title":"indigo_400","content":"pub const indigo_400: Color\n\nSynonyms:\nkitten/color.indigo_400\nkitten/color indigo_400","url":"kitten/color.html#indigo_400"},{"doc":"kitten/color","title":"indigo_450","content":"pub const indigo_450: Color\n\nSynonyms:\nkitten/color.indigo_450\nkitten/color indigo_450","url":"kitten/color.html#indigo_450"},{"doc":"kitten/color","title":"indigo_500","content":"pub const indigo_500: Color\n\nSynonyms:\nkitten/color.indigo_500\nkitten/color indigo_500","url":"kitten/color.html#indigo_500"},{"doc":"kitten/color","title":"indigo_550","content":"pub const indigo_550: Color\n\nSynonyms:\nkitten/color.indigo_550\nkitten/color indigo_550","url":"kitten/color.html#indigo_550"},{"doc":"kitten/color","title":"indigo_600","content":"pub const indigo_600: Color\n\nSynonyms:\nkitten/color.indigo_600\nkitten/color indigo_600","url":"kitten/color.html#indigo_600"},{"doc":"kitten/color","title":"indigo_650","content":"pub const indigo_650: Color\n\nSynonyms:\nkitten/color.indigo_650\nkitten/color indigo_650","url":"kitten/color.html#indigo_650"},{"doc":"kitten/color","title":"indigo_700","content":"pub const indigo_700: Color\n\nSynonyms:\nkitten/color.indigo_700\nkitten/color indigo_700","url":"kitten/color.html#indigo_700"},{"doc":"kitten/color","title":"indigo_750","content":"pub const indigo_750: Color\n\nSynonyms:\nkitten/color.indigo_750\nkitten/color indigo_750","url":"kitten/color.html#indigo_750"},{"doc":"kitten/color","title":"indigo_800","content":"pub const indigo_800: Color\n\nSynonyms:\nkitten/color.indigo_800\nkitten/color indigo_800","url":"kitten/color.html#indigo_800"},{"doc":"kitten/color","title":"indigo_850","content":"pub const indigo_850: Color\n\nSynonyms:\nkitten/color.indigo_850\nkitten/color indigo_850","url":"kitten/color.html#indigo_850"},{"doc":"kitten/color","title":"indigo_900","content":"pub const indigo_900: Color\n\nSynonyms:\nkitten/color.indigo_900\nkitten/color indigo_900","url":"kitten/color.html#indigo_900"},{"doc":"kitten/color","title":"indigo_950","content":"pub const indigo_950: Color\n\nSynonyms:\nkitten/color.indigo_950\nkitten/color indigo_950","url":"kitten/color.html#indigo_950"},{"doc":"kitten/color","title":"jade","content":"pub const jade: Color\n\nSynonyms:\nkitten/color.jade\nkitten/color jade","url":"kitten/color.html#jade"},{"doc":"kitten/color","title":"jade_050","content":"pub const jade_050: Color\n\nSynonyms:\nkitten/color.jade_050\nkitten/color jade_050","url":"kitten/color.html#jade_050"},{"doc":"kitten/color","title":"jade_100","content":"pub const jade_100: Color\n\nSynonyms:\nkitten/color.jade_100\nkitten/color jade_100","url":"kitten/color.html#jade_100"},{"doc":"kitten/color","title":"jade_150","content":"pub const jade_150: Color\n\nSynonyms:\nkitten/color.jade_150\nkitten/color jade_150","url":"kitten/color.html#jade_150"},{"doc":"kitten/color","title":"jade_200","content":"pub const jade_200: Color\n\nSynonyms:\nkitten/color.jade_200\nkitten/color jade_200","url":"kitten/color.html#jade_200"},{"doc":"kitten/color","title":"jade_250","content":"pub const jade_250: Color\n\nSynonyms:\nkitten/color.jade_250\nkitten/color jade_250","url":"kitten/color.html#jade_250"},{"doc":"kitten/color","title":"jade_300","content":"pub const jade_300: Color\n\nSynonyms:\nkitten/color.jade_300\nkitten/color jade_300","url":"kitten/color.html#jade_300"},{"doc":"kitten/color","title":"jade_350","content":"pub const jade_350: Color\n\nSynonyms:\nkitten/color.jade_350\nkitten/color jade_350","url":"kitten/color.html#jade_350"},{"doc":"kitten/color","title":"jade_400","content":"pub const jade_400: Color\n\nSynonyms:\nkitten/color.jade_400\nkitten/color jade_400","url":"kitten/color.html#jade_400"},{"doc":"kitten/color","title":"jade_450","content":"pub const jade_450: Color\n\nSynonyms:\nkitten/color.jade_450\nkitten/color jade_450","url":"kitten/color.html#jade_450"},{"doc":"kitten/color","title":"jade_500","content":"pub const jade_500: Color\n\nSynonyms:\nkitten/color.jade_500\nkitten/color jade_500","url":"kitten/color.html#jade_500"},{"doc":"kitten/color","title":"jade_550","content":"pub const jade_550: Color\n\nSynonyms:\nkitten/color.jade_550\nkitten/color jade_550","url":"kitten/color.html#jade_550"},{"doc":"kitten/color","title":"jade_600","content":"pub const jade_600: Color\n\nSynonyms:\nkitten/color.jade_600\nkitten/color jade_600","url":"kitten/color.html#jade_600"},{"doc":"kitten/color","title":"jade_650","content":"pub const jade_650: Color\n\nSynonyms:\nkitten/color.jade_650\nkitten/color jade_650","url":"kitten/color.html#jade_650"},{"doc":"kitten/color","title":"jade_700","content":"pub const jade_700: Color\n\nSynonyms:\nkitten/color.jade_700\nkitten/color jade_700","url":"kitten/color.html#jade_700"},{"doc":"kitten/color","title":"jade_750","content":"pub const jade_750: Color\n\nSynonyms:\nkitten/color.jade_750\nkitten/color jade_750","url":"kitten/color.html#jade_750"},{"doc":"kitten/color","title":"jade_800","content":"pub const jade_800: Color\n\nSynonyms:\nkitten/color.jade_800\nkitten/color jade_800","url":"kitten/color.html#jade_800"},{"doc":"kitten/color","title":"jade_850","content":"pub const jade_850: Color\n\nSynonyms:\nkitten/color.jade_850\nkitten/color jade_850","url":"kitten/color.html#jade_850"},{"doc":"kitten/color","title":"jade_900","content":"pub const jade_900: Color\n\nSynonyms:\nkitten/color.jade_900\nkitten/color jade_900","url":"kitten/color.html#jade_900"},{"doc":"kitten/color","title":"jade_950","content":"pub const jade_950: Color\n\nSynonyms:\nkitten/color.jade_950\nkitten/color jade_950","url":"kitten/color.html#jade_950"},{"doc":"kitten/color","title":"lime","content":"pub const lime: Color\n\nSynonyms:\nkitten/color.lime\nkitten/color lime","url":"kitten/color.html#lime"},{"doc":"kitten/color","title":"lime_050","content":"pub const lime_050: Color\n\nSynonyms:\nkitten/color.lime_050\nkitten/color lime_050","url":"kitten/color.html#lime_050"},{"doc":"kitten/color","title":"lime_100","content":"pub const lime_100: Color\n\nSynonyms:\nkitten/color.lime_100\nkitten/color lime_100","url":"kitten/color.html#lime_100"},{"doc":"kitten/color","title":"lime_150","content":"pub const lime_150: Color\n\nSynonyms:\nkitten/color.lime_150\nkitten/color lime_150","url":"kitten/color.html#lime_150"},{"doc":"kitten/color","title":"lime_200","content":"pub const lime_200: Color\n\nSynonyms:\nkitten/color.lime_200\nkitten/color lime_200","url":"kitten/color.html#lime_200"},{"doc":"kitten/color","title":"lime_250","content":"pub const lime_250: Color\n\nSynonyms:\nkitten/color.lime_250\nkitten/color lime_250","url":"kitten/color.html#lime_250"},{"doc":"kitten/color","title":"lime_300","content":"pub const lime_300: Color\n\nSynonyms:\nkitten/color.lime_300\nkitten/color lime_300","url":"kitten/color.html#lime_300"},{"doc":"kitten/color","title":"lime_350","content":"pub const lime_350: Color\n\nSynonyms:\nkitten/color.lime_350\nkitten/color lime_350","url":"kitten/color.html#lime_350"},{"doc":"kitten/color","title":"lime_400","content":"pub const lime_400: Color\n\nSynonyms:\nkitten/color.lime_400\nkitten/color lime_400","url":"kitten/color.html#lime_400"},{"doc":"kitten/color","title":"lime_450","content":"pub const lime_450: Color\n\nSynonyms:\nkitten/color.lime_450\nkitten/color lime_450","url":"kitten/color.html#lime_450"},{"doc":"kitten/color","title":"lime_500","content":"pub const lime_500: Color\n\nSynonyms:\nkitten/color.lime_500\nkitten/color lime_500","url":"kitten/color.html#lime_500"},{"doc":"kitten/color","title":"lime_550","content":"pub const lime_550: Color\n\nSynonyms:\nkitten/color.lime_550\nkitten/color lime_550","url":"kitten/color.html#lime_550"},{"doc":"kitten/color","title":"lime_600","content":"pub const lime_600: Color\n\nSynonyms:\nkitten/color.lime_600\nkitten/color lime_600","url":"kitten/color.html#lime_600"},{"doc":"kitten/color","title":"lime_650","content":"pub const lime_650: Color\n\nSynonyms:\nkitten/color.lime_650\nkitten/color lime_650","url":"kitten/color.html#lime_650"},{"doc":"kitten/color","title":"lime_700","content":"pub const lime_700: Color\n\nSynonyms:\nkitten/color.lime_700\nkitten/color lime_700","url":"kitten/color.html#lime_700"},{"doc":"kitten/color","title":"lime_750","content":"pub const lime_750: Color\n\nSynonyms:\nkitten/color.lime_750\nkitten/color lime_750","url":"kitten/color.html#lime_750"},{"doc":"kitten/color","title":"lime_800","content":"pub const lime_800: Color\n\nSynonyms:\nkitten/color.lime_800\nkitten/color lime_800","url":"kitten/color.html#lime_800"},{"doc":"kitten/color","title":"lime_850","content":"pub const lime_850: Color\n\nSynonyms:\nkitten/color.lime_850\nkitten/color lime_850","url":"kitten/color.html#lime_850"},{"doc":"kitten/color","title":"lime_900","content":"pub const lime_900: Color\n\nSynonyms:\nkitten/color.lime_900\nkitten/color lime_900","url":"kitten/color.html#lime_900"},{"doc":"kitten/color","title":"lime_950","content":"pub const lime_950: Color\n\nSynonyms:\nkitten/color.lime_950\nkitten/color lime_950","url":"kitten/color.html#lime_950"},{"doc":"kitten/color","title":"orange","content":"pub const orange: Color\n\nSynonyms:\nkitten/color.orange\nkitten/color orange","url":"kitten/color.html#orange"},{"doc":"kitten/color","title":"orange_050","content":"pub const orange_050: Color\n\nSynonyms:\nkitten/color.orange_050\nkitten/color orange_050","url":"kitten/color.html#orange_050"},{"doc":"kitten/color","title":"orange_100","content":"pub const orange_100: Color\n\nSynonyms:\nkitten/color.orange_100\nkitten/color orange_100","url":"kitten/color.html#orange_100"},{"doc":"kitten/color","title":"orange_150","content":"pub const orange_150: Color\n\nSynonyms:\nkitten/color.orange_150\nkitten/color orange_150","url":"kitten/color.html#orange_150"},{"doc":"kitten/color","title":"orange_200","content":"pub const orange_200: Color\n\nSynonyms:\nkitten/color.orange_200\nkitten/color orange_200","url":"kitten/color.html#orange_200"},{"doc":"kitten/color","title":"orange_250","content":"pub const orange_250: Color\n\nSynonyms:\nkitten/color.orange_250\nkitten/color orange_250","url":"kitten/color.html#orange_250"},{"doc":"kitten/color","title":"orange_300","content":"pub const orange_300: Color\n\nSynonyms:\nkitten/color.orange_300\nkitten/color orange_300","url":"kitten/color.html#orange_300"},{"doc":"kitten/color","title":"orange_350","content":"pub const orange_350: Color\n\nSynonyms:\nkitten/color.orange_350\nkitten/color orange_350","url":"kitten/color.html#orange_350"},{"doc":"kitten/color","title":"orange_400","content":"pub const orange_400: Color\n\nSynonyms:\nkitten/color.orange_400\nkitten/color orange_400","url":"kitten/color.html#orange_400"},{"doc":"kitten/color","title":"orange_450","content":"pub const orange_450: Color\n\nSynonyms:\nkitten/color.orange_450\nkitten/color orange_450","url":"kitten/color.html#orange_450"},{"doc":"kitten/color","title":"orange_500","content":"pub const orange_500: Color\n\nSynonyms:\nkitten/color.orange_500\nkitten/color orange_500","url":"kitten/color.html#orange_500"},{"doc":"kitten/color","title":"orange_550","content":"pub const orange_550: Color\n\nSynonyms:\nkitten/color.orange_550\nkitten/color orange_550","url":"kitten/color.html#orange_550"},{"doc":"kitten/color","title":"orange_600","content":"pub const orange_600: Color\n\nSynonyms:\nkitten/color.orange_600\nkitten/color orange_600","url":"kitten/color.html#orange_600"},{"doc":"kitten/color","title":"orange_650","content":"pub const orange_650: Color\n\nSynonyms:\nkitten/color.orange_650\nkitten/color orange_650","url":"kitten/color.html#orange_650"},{"doc":"kitten/color","title":"orange_700","content":"pub const orange_700: Color\n\nSynonyms:\nkitten/color.orange_700\nkitten/color orange_700","url":"kitten/color.html#orange_700"},{"doc":"kitten/color","title":"orange_750","content":"pub const orange_750: Color\n\nSynonyms:\nkitten/color.orange_750\nkitten/color orange_750","url":"kitten/color.html#orange_750"},{"doc":"kitten/color","title":"orange_800","content":"pub const orange_800: Color\n\nSynonyms:\nkitten/color.orange_800\nkitten/color orange_800","url":"kitten/color.html#orange_800"},{"doc":"kitten/color","title":"orange_850","content":"pub const orange_850: Color\n\nSynonyms:\nkitten/color.orange_850\nkitten/color orange_850","url":"kitten/color.html#orange_850"},{"doc":"kitten/color","title":"orange_900","content":"pub const orange_900: Color\n\nSynonyms:\nkitten/color.orange_900\nkitten/color orange_900","url":"kitten/color.html#orange_900"},{"doc":"kitten/color","title":"orange_950","content":"pub const orange_950: Color\n\nSynonyms:\nkitten/color.orange_950\nkitten/color orange_950","url":"kitten/color.html#orange_950"},{"doc":"kitten/color","title":"pink","content":"pub const pink: Color\n\nSynonyms:\nkitten/color.pink\nkitten/color pink","url":"kitten/color.html#pink"},{"doc":"kitten/color","title":"pink_050","content":"pub const pink_050: Color\n\nSynonyms:\nkitten/color.pink_050\nkitten/color pink_050","url":"kitten/color.html#pink_050"},{"doc":"kitten/color","title":"pink_100","content":"pub const pink_100: Color\n\nSynonyms:\nkitten/color.pink_100\nkitten/color pink_100","url":"kitten/color.html#pink_100"},{"doc":"kitten/color","title":"pink_150","content":"pub const pink_150: Color\n\nSynonyms:\nkitten/color.pink_150\nkitten/color pink_150","url":"kitten/color.html#pink_150"},{"doc":"kitten/color","title":"pink_200","content":"pub const pink_200: Color\n\nSynonyms:\nkitten/color.pink_200\nkitten/color pink_200","url":"kitten/color.html#pink_200"},{"doc":"kitten/color","title":"pink_250","content":"pub const pink_250: Color\n\nSynonyms:\nkitten/color.pink_250\nkitten/color pink_250","url":"kitten/color.html#pink_250"},{"doc":"kitten/color","title":"pink_300","content":"pub const pink_300: Color\n\nSynonyms:\nkitten/color.pink_300\nkitten/color pink_300","url":"kitten/color.html#pink_300"},{"doc":"kitten/color","title":"pink_350","content":"pub const pink_350: Color\n\nSynonyms:\nkitten/color.pink_350\nkitten/color pink_350","url":"kitten/color.html#pink_350"},{"doc":"kitten/color","title":"pink_400","content":"pub const pink_400: Color\n\nSynonyms:\nkitten/color.pink_400\nkitten/color pink_400","url":"kitten/color.html#pink_400"},{"doc":"kitten/color","title":"pink_450","content":"pub const pink_450: Color\n\nSynonyms:\nkitten/color.pink_450\nkitten/color pink_450","url":"kitten/color.html#pink_450"},{"doc":"kitten/color","title":"pink_500","content":"pub const pink_500: Color\n\nSynonyms:\nkitten/color.pink_500\nkitten/color pink_500","url":"kitten/color.html#pink_500"},{"doc":"kitten/color","title":"pink_550","content":"pub const pink_550: Color\n\nSynonyms:\nkitten/color.pink_550\nkitten/color pink_550","url":"kitten/color.html#pink_550"},{"doc":"kitten/color","title":"pink_600","content":"pub const pink_600: Color\n\nSynonyms:\nkitten/color.pink_600\nkitten/color pink_600","url":"kitten/color.html#pink_600"},{"doc":"kitten/color","title":"pink_650","content":"pub const pink_650: Color\n\nSynonyms:\nkitten/color.pink_650\nkitten/color pink_650","url":"kitten/color.html#pink_650"},{"doc":"kitten/color","title":"pink_700","content":"pub const pink_700: Color\n\nSynonyms:\nkitten/color.pink_700\nkitten/color pink_700","url":"kitten/color.html#pink_700"},{"doc":"kitten/color","title":"pink_750","content":"pub const pink_750: Color\n\nSynonyms:\nkitten/color.pink_750\nkitten/color pink_750","url":"kitten/color.html#pink_750"},{"doc":"kitten/color","title":"pink_800","content":"pub const pink_800: Color\n\nSynonyms:\nkitten/color.pink_800\nkitten/color pink_800","url":"kitten/color.html#pink_800"},{"doc":"kitten/color","title":"pink_850","content":"pub const pink_850: Color\n\nSynonyms:\nkitten/color.pink_850\nkitten/color pink_850","url":"kitten/color.html#pink_850"},{"doc":"kitten/color","title":"pink_900","content":"pub const pink_900: Color\n\nSynonyms:\nkitten/color.pink_900\nkitten/color pink_900","url":"kitten/color.html#pink_900"},{"doc":"kitten/color","title":"pink_950","content":"pub const pink_950: Color\n\nSynonyms:\nkitten/color.pink_950\nkitten/color pink_950","url":"kitten/color.html#pink_950"},{"doc":"kitten/color","title":"pumpkin","content":"pub const pumpkin: Color\n\nSynonyms:\nkitten/color.pumpkin\nkitten/color pumpkin","url":"kitten/color.html#pumpkin"},{"doc":"kitten/color","title":"pumpkin_050","content":"pub const pumpkin_050: Color\n\nSynonyms:\nkitten/color.pumpkin_050\nkitten/color pumpkin_050","url":"kitten/color.html#pumpkin_050"},{"doc":"kitten/color","title":"pumpkin_100","content":"pub const pumpkin_100: Color\n\nSynonyms:\nkitten/color.pumpkin_100\nkitten/color pumpkin_100","url":"kitten/color.html#pumpkin_100"},{"doc":"kitten/color","title":"pumpkin_150","content":"pub const pumpkin_150: Color\n\nSynonyms:\nkitten/color.pumpkin_150\nkitten/color pumpkin_150","url":"kitten/color.html#pumpkin_150"},{"doc":"kitten/color","title":"pumpkin_200","content":"pub const pumpkin_200: Color\n\nSynonyms:\nkitten/color.pumpkin_200\nkitten/color pumpkin_200","url":"kitten/color.html#pumpkin_200"},{"doc":"kitten/color","title":"pumpkin_250","content":"pub const pumpkin_250: Color\n\nSynonyms:\nkitten/color.pumpkin_250\nkitten/color pumpkin_250","url":"kitten/color.html#pumpkin_250"},{"doc":"kitten/color","title":"pumpkin_300","content":"pub const pumpkin_300: Color\n\nSynonyms:\nkitten/color.pumpkin_300\nkitten/color pumpkin_300","url":"kitten/color.html#pumpkin_300"},{"doc":"kitten/color","title":"pumpkin_350","content":"pub const pumpkin_350: Color\n\nSynonyms:\nkitten/color.pumpkin_350\nkitten/color pumpkin_350","url":"kitten/color.html#pumpkin_350"},{"doc":"kitten/color","title":"pumpkin_400","content":"pub const pumpkin_400: Color\n\nSynonyms:\nkitten/color.pumpkin_400\nkitten/color pumpkin_400","url":"kitten/color.html#pumpkin_400"},{"doc":"kitten/color","title":"pumpkin_450","content":"pub const pumpkin_450: Color\n\nSynonyms:\nkitten/color.pumpkin_450\nkitten/color pumpkin_450","url":"kitten/color.html#pumpkin_450"},{"doc":"kitten/color","title":"pumpkin_500","content":"pub const pumpkin_500: Color\n\nSynonyms:\nkitten/color.pumpkin_500\nkitten/color pumpkin_500","url":"kitten/color.html#pumpkin_500"},{"doc":"kitten/color","title":"pumpkin_550","content":"pub const pumpkin_550: Color\n\nSynonyms:\nkitten/color.pumpkin_550\nkitten/color pumpkin_550","url":"kitten/color.html#pumpkin_550"},{"doc":"kitten/color","title":"pumpkin_600","content":"pub const pumpkin_600: Color\n\nSynonyms:\nkitten/color.pumpkin_600\nkitten/color pumpkin_600","url":"kitten/color.html#pumpkin_600"},{"doc":"kitten/color","title":"pumpkin_650","content":"pub const pumpkin_650: Color\n\nSynonyms:\nkitten/color.pumpkin_650\nkitten/color pumpkin_650","url":"kitten/color.html#pumpkin_650"},{"doc":"kitten/color","title":"pumpkin_700","content":"pub const pumpkin_700: Color\n\nSynonyms:\nkitten/color.pumpkin_700\nkitten/color pumpkin_700","url":"kitten/color.html#pumpkin_700"},{"doc":"kitten/color","title":"pumpkin_750","content":"pub const pumpkin_750: Color\n\nSynonyms:\nkitten/color.pumpkin_750\nkitten/color pumpkin_750","url":"kitten/color.html#pumpkin_750"},{"doc":"kitten/color","title":"pumpkin_800","content":"pub const pumpkin_800: Color\n\nSynonyms:\nkitten/color.pumpkin_800\nkitten/color pumpkin_800","url":"kitten/color.html#pumpkin_800"},{"doc":"kitten/color","title":"pumpkin_850","content":"pub const pumpkin_850: Color\n\nSynonyms:\nkitten/color.pumpkin_850\nkitten/color pumpkin_850","url":"kitten/color.html#pumpkin_850"},{"doc":"kitten/color","title":"pumpkin_900","content":"pub const pumpkin_900: Color\n\nSynonyms:\nkitten/color.pumpkin_900\nkitten/color pumpkin_900","url":"kitten/color.html#pumpkin_900"},{"doc":"kitten/color","title":"pumpkin_950","content":"pub const pumpkin_950: Color\n\nSynonyms:\nkitten/color.pumpkin_950\nkitten/color pumpkin_950","url":"kitten/color.html#pumpkin_950"},{"doc":"kitten/color","title":"purple","content":"pub const purple: Color\n\nSynonyms:\nkitten/color.purple\nkitten/color purple","url":"kitten/color.html#purple"},{"doc":"kitten/color","title":"purple_050","content":"pub const purple_050: Color\n\nSynonyms:\nkitten/color.purple_050\nkitten/color purple_050","url":"kitten/color.html#purple_050"},{"doc":"kitten/color","title":"purple_100","content":"pub const purple_100: Color\n\nSynonyms:\nkitten/color.purple_100\nkitten/color purple_100","url":"kitten/color.html#purple_100"},{"doc":"kitten/color","title":"purple_150","content":"pub const purple_150: Color\n\nSynonyms:\nkitten/color.purple_150\nkitten/color purple_150","url":"kitten/color.html#purple_150"},{"doc":"kitten/color","title":"purple_200","content":"pub const purple_200: Color\n\nSynonyms:\nkitten/color.purple_200\nkitten/color purple_200","url":"kitten/color.html#purple_200"},{"doc":"kitten/color","title":"purple_250","content":"pub const purple_250: Color\n\nSynonyms:\nkitten/color.purple_250\nkitten/color purple_250","url":"kitten/color.html#purple_250"},{"doc":"kitten/color","title":"purple_300","content":"pub const purple_300: Color\n\nSynonyms:\nkitten/color.purple_300\nkitten/color purple_300","url":"kitten/color.html#purple_300"},{"doc":"kitten/color","title":"purple_350","content":"pub const purple_350: Color\n\nSynonyms:\nkitten/color.purple_350\nkitten/color purple_350","url":"kitten/color.html#purple_350"},{"doc":"kitten/color","title":"purple_400","content":"pub const purple_400: Color\n\nSynonyms:\nkitten/color.purple_400\nkitten/color purple_400","url":"kitten/color.html#purple_400"},{"doc":"kitten/color","title":"purple_450","content":"pub const purple_450: Color\n\nSynonyms:\nkitten/color.purple_450\nkitten/color purple_450","url":"kitten/color.html#purple_450"},{"doc":"kitten/color","title":"purple_500","content":"pub const purple_500: Color\n\nSynonyms:\nkitten/color.purple_500\nkitten/color purple_500","url":"kitten/color.html#purple_500"},{"doc":"kitten/color","title":"purple_550","content":"pub const purple_550: Color\n\nSynonyms:\nkitten/color.purple_550\nkitten/color purple_550","url":"kitten/color.html#purple_550"},{"doc":"kitten/color","title":"purple_600","content":"pub const purple_600: Color\n\nSynonyms:\nkitten/color.purple_600\nkitten/color purple_600","url":"kitten/color.html#purple_600"},{"doc":"kitten/color","title":"purple_650","content":"pub const purple_650: Color\n\nSynonyms:\nkitten/color.purple_650\nkitten/color purple_650","url":"kitten/color.html#purple_650"},{"doc":"kitten/color","title":"purple_700","content":"pub const purple_700: Color\n\nSynonyms:\nkitten/color.purple_700\nkitten/color purple_700","url":"kitten/color.html#purple_700"},{"doc":"kitten/color","title":"purple_750","content":"pub const purple_750: Color\n\nSynonyms:\nkitten/color.purple_750\nkitten/color purple_750","url":"kitten/color.html#purple_750"},{"doc":"kitten/color","title":"purple_800","content":"pub const purple_800: Color\n\nSynonyms:\nkitten/color.purple_800\nkitten/color purple_800","url":"kitten/color.html#purple_800"},{"doc":"kitten/color","title":"purple_850","content":"pub const purple_850: Color\n\nSynonyms:\nkitten/color.purple_850\nkitten/color purple_850","url":"kitten/color.html#purple_850"},{"doc":"kitten/color","title":"purple_900","content":"pub const purple_900: Color\n\nSynonyms:\nkitten/color.purple_900\nkitten/color purple_900","url":"kitten/color.html#purple_900"},{"doc":"kitten/color","title":"purple_950","content":"pub const purple_950: Color\n\nSynonyms:\nkitten/color.purple_950\nkitten/color purple_950","url":"kitten/color.html#purple_950"},{"doc":"kitten/color","title":"red","content":"pub const red: Color\n\nSynonyms:\nkitten/color.red\nkitten/color red","url":"kitten/color.html#red"},{"doc":"kitten/color","title":"red_050","content":"pub const red_050: Color\n\nSynonyms:\nkitten/color.red_050\nkitten/color red_050","url":"kitten/color.html#red_050"},{"doc":"kitten/color","title":"red_100","content":"pub const red_100: Color\n\nSynonyms:\nkitten/color.red_100\nkitten/color red_100","url":"kitten/color.html#red_100"},{"doc":"kitten/color","title":"red_150","content":"pub const red_150: Color\n\nSynonyms:\nkitten/color.red_150\nkitten/color red_150","url":"kitten/color.html#red_150"},{"doc":"kitten/color","title":"red_200","content":"pub const red_200: Color\n\nSynonyms:\nkitten/color.red_200\nkitten/color red_200","url":"kitten/color.html#red_200"},{"doc":"kitten/color","title":"red_250","content":"pub const red_250: Color\n\nSynonyms:\nkitten/color.red_250\nkitten/color red_250","url":"kitten/color.html#red_250"},{"doc":"kitten/color","title":"red_300","content":"pub const red_300: Color\n\nSynonyms:\nkitten/color.red_300\nkitten/color red_300","url":"kitten/color.html#red_300"},{"doc":"kitten/color","title":"red_350","content":"pub const red_350: Color\n\nSynonyms:\nkitten/color.red_350\nkitten/color red_350","url":"kitten/color.html#red_350"},{"doc":"kitten/color","title":"red_400","content":"pub const red_400: Color\n\nSynonyms:\nkitten/color.red_400\nkitten/color red_400","url":"kitten/color.html#red_400"},{"doc":"kitten/color","title":"red_450","content":"pub const red_450: Color\n\nSynonyms:\nkitten/color.red_450\nkitten/color red_450","url":"kitten/color.html#red_450"},{"doc":"kitten/color","title":"red_500","content":"pub const red_500: Color\n\nSynonyms:\nkitten/color.red_500\nkitten/color red_500","url":"kitten/color.html#red_500"},{"doc":"kitten/color","title":"red_550","content":"pub const red_550: Color\n\nSynonyms:\nkitten/color.red_550\nkitten/color red_550","url":"kitten/color.html#red_550"},{"doc":"kitten/color","title":"red_600","content":"pub const red_600: Color\n\nSynonyms:\nkitten/color.red_600\nkitten/color red_600","url":"kitten/color.html#red_600"},{"doc":"kitten/color","title":"red_650","content":"pub const red_650: Color\n\nSynonyms:\nkitten/color.red_650\nkitten/color red_650","url":"kitten/color.html#red_650"},{"doc":"kitten/color","title":"red_700","content":"pub const red_700: Color\n\nSynonyms:\nkitten/color.red_700\nkitten/color red_700","url":"kitten/color.html#red_700"},{"doc":"kitten/color","title":"red_750","content":"pub const red_750: Color\n\nSynonyms:\nkitten/color.red_750\nkitten/color red_750","url":"kitten/color.html#red_750"},{"doc":"kitten/color","title":"red_800","content":"pub const red_800: Color\n\nSynonyms:\nkitten/color.red_800\nkitten/color red_800","url":"kitten/color.html#red_800"},{"doc":"kitten/color","title":"red_850","content":"pub const red_850: Color\n\nSynonyms:\nkitten/color.red_850\nkitten/color red_850","url":"kitten/color.html#red_850"},{"doc":"kitten/color","title":"red_900","content":"pub const red_900: Color\n\nSynonyms:\nkitten/color.red_900\nkitten/color red_900","url":"kitten/color.html#red_900"},{"doc":"kitten/color","title":"red_950","content":"pub const red_950: Color\n\nSynonyms:\nkitten/color.red_950\nkitten/color red_950","url":"kitten/color.html#red_950"},{"doc":"kitten/color","title":"sand","content":"pub const sand: Color\n\nSynonyms:\nkitten/color.sand\nkitten/color sand","url":"kitten/color.html#sand"},{"doc":"kitten/color","title":"sand_050","content":"pub const sand_050: Color\n\nSynonyms:\nkitten/color.sand_050\nkitten/color sand_050","url":"kitten/color.html#sand_050"},{"doc":"kitten/color","title":"sand_100","content":"pub const sand_100: Color\n\nSynonyms:\nkitten/color.sand_100\nkitten/color sand_100","url":"kitten/color.html#sand_100"},{"doc":"kitten/color","title":"sand_150","content":"pub const sand_150: Color\n\nSynonyms:\nkitten/color.sand_150\nkitten/color sand_150","url":"kitten/color.html#sand_150"},{"doc":"kitten/color","title":"sand_200","content":"pub const sand_200: Color\n\nSynonyms:\nkitten/color.sand_200\nkitten/color sand_200","url":"kitten/color.html#sand_200"},{"doc":"kitten/color","title":"sand_250","content":"pub const sand_250: Color\n\nSynonyms:\nkitten/color.sand_250\nkitten/color sand_250","url":"kitten/color.html#sand_250"},{"doc":"kitten/color","title":"sand_300","content":"pub const sand_300: Color\n\nSynonyms:\nkitten/color.sand_300\nkitten/color sand_300","url":"kitten/color.html#sand_300"},{"doc":"kitten/color","title":"sand_350","content":"pub const sand_350: Color\n\nSynonyms:\nkitten/color.sand_350\nkitten/color sand_350","url":"kitten/color.html#sand_350"},{"doc":"kitten/color","title":"sand_400","content":"pub const sand_400: Color\n\nSynonyms:\nkitten/color.sand_400\nkitten/color sand_400","url":"kitten/color.html#sand_400"},{"doc":"kitten/color","title":"sand_450","content":"pub const sand_450: Color\n\nSynonyms:\nkitten/color.sand_450\nkitten/color sand_450","url":"kitten/color.html#sand_450"},{"doc":"kitten/color","title":"sand_500","content":"pub const sand_500: Color\n\nSynonyms:\nkitten/color.sand_500\nkitten/color sand_500","url":"kitten/color.html#sand_500"},{"doc":"kitten/color","title":"sand_550","content":"pub const sand_550: Color\n\nSynonyms:\nkitten/color.sand_550\nkitten/color sand_550","url":"kitten/color.html#sand_550"},{"doc":"kitten/color","title":"sand_600","content":"pub const sand_600: Color\n\nSynonyms:\nkitten/color.sand_600\nkitten/color sand_600","url":"kitten/color.html#sand_600"},{"doc":"kitten/color","title":"sand_650","content":"pub const sand_650: Color\n\nSynonyms:\nkitten/color.sand_650\nkitten/color sand_650","url":"kitten/color.html#sand_650"},{"doc":"kitten/color","title":"sand_700","content":"pub const sand_700: Color\n\nSynonyms:\nkitten/color.sand_700\nkitten/color sand_700","url":"kitten/color.html#sand_700"},{"doc":"kitten/color","title":"sand_750","content":"pub const sand_750: Color\n\nSynonyms:\nkitten/color.sand_750\nkitten/color sand_750","url":"kitten/color.html#sand_750"},{"doc":"kitten/color","title":"sand_800","content":"pub const sand_800: Color\n\nSynonyms:\nkitten/color.sand_800\nkitten/color sand_800","url":"kitten/color.html#sand_800"},{"doc":"kitten/color","title":"sand_850","content":"pub const sand_850: Color\n\nSynonyms:\nkitten/color.sand_850\nkitten/color sand_850","url":"kitten/color.html#sand_850"},{"doc":"kitten/color","title":"sand_900","content":"pub const sand_900: Color\n\nSynonyms:\nkitten/color.sand_900\nkitten/color sand_900","url":"kitten/color.html#sand_900"},{"doc":"kitten/color","title":"sand_950","content":"pub const sand_950: Color\n\nSynonyms:\nkitten/color.sand_950\nkitten/color sand_950","url":"kitten/color.html#sand_950"},{"doc":"kitten/color","title":"slate","content":"pub const slate: Color\n\nSynonyms:\nkitten/color.slate\nkitten/color slate","url":"kitten/color.html#slate"},{"doc":"kitten/color","title":"slate_050","content":"pub const slate_050: Color\n\nSynonyms:\nkitten/color.slate_050\nkitten/color slate_050","url":"kitten/color.html#slate_050"},{"doc":"kitten/color","title":"slate_100","content":"pub const slate_100: Color\n\nSynonyms:\nkitten/color.slate_100\nkitten/color slate_100","url":"kitten/color.html#slate_100"},{"doc":"kitten/color","title":"slate_150","content":"pub const slate_150: Color\n\nSynonyms:\nkitten/color.slate_150\nkitten/color slate_150","url":"kitten/color.html#slate_150"},{"doc":"kitten/color","title":"slate_200","content":"pub const slate_200: Color\n\nSynonyms:\nkitten/color.slate_200\nkitten/color slate_200","url":"kitten/color.html#slate_200"},{"doc":"kitten/color","title":"slate_250","content":"pub const slate_250: Color\n\nSynonyms:\nkitten/color.slate_250\nkitten/color slate_250","url":"kitten/color.html#slate_250"},{"doc":"kitten/color","title":"slate_300","content":"pub const slate_300: Color\n\nSynonyms:\nkitten/color.slate_300\nkitten/color slate_300","url":"kitten/color.html#slate_300"},{"doc":"kitten/color","title":"slate_350","content":"pub const slate_350: Color\n\nSynonyms:\nkitten/color.slate_350\nkitten/color slate_350","url":"kitten/color.html#slate_350"},{"doc":"kitten/color","title":"slate_400","content":"pub const slate_400: Color\n\nSynonyms:\nkitten/color.slate_400\nkitten/color slate_400","url":"kitten/color.html#slate_400"},{"doc":"kitten/color","title":"slate_450","content":"pub const slate_450: Color\n\nSynonyms:\nkitten/color.slate_450\nkitten/color slate_450","url":"kitten/color.html#slate_450"},{"doc":"kitten/color","title":"slate_500","content":"pub const slate_500: Color\n\nSynonyms:\nkitten/color.slate_500\nkitten/color slate_500","url":"kitten/color.html#slate_500"},{"doc":"kitten/color","title":"slate_550","content":"pub const slate_550: Color\n\nSynonyms:\nkitten/color.slate_550\nkitten/color slate_550","url":"kitten/color.html#slate_550"},{"doc":"kitten/color","title":"slate_600","content":"pub const slate_600: Color\n\nSynonyms:\nkitten/color.slate_600\nkitten/color slate_600","url":"kitten/color.html#slate_600"},{"doc":"kitten/color","title":"slate_650","content":"pub const slate_650: Color\n\nSynonyms:\nkitten/color.slate_650\nkitten/color slate_650","url":"kitten/color.html#slate_650"},{"doc":"kitten/color","title":"slate_700","content":"pub const slate_700: Color\n\nSynonyms:\nkitten/color.slate_700\nkitten/color slate_700","url":"kitten/color.html#slate_700"},{"doc":"kitten/color","title":"slate_750","content":"pub const slate_750: Color\n\nSynonyms:\nkitten/color.slate_750\nkitten/color slate_750","url":"kitten/color.html#slate_750"},{"doc":"kitten/color","title":"slate_800","content":"pub const slate_800: Color\n\nSynonyms:\nkitten/color.slate_800\nkitten/color slate_800","url":"kitten/color.html#slate_800"},{"doc":"kitten/color","title":"slate_850","content":"pub const slate_850: Color\n\nSynonyms:\nkitten/color.slate_850\nkitten/color slate_850","url":"kitten/color.html#slate_850"},{"doc":"kitten/color","title":"slate_900","content":"pub const slate_900: Color\n\nSynonyms:\nkitten/color.slate_900\nkitten/color slate_900","url":"kitten/color.html#slate_900"},{"doc":"kitten/color","title":"slate_950","content":"pub const slate_950: Color\n\nSynonyms:\nkitten/color.slate_950\nkitten/color slate_950","url":"kitten/color.html#slate_950"},{"doc":"kitten/color","title":"violet","content":"pub const violet: Color\n\nSynonyms:\nkitten/color.violet\nkitten/color violet","url":"kitten/color.html#violet"},{"doc":"kitten/color","title":"violet_050","content":"pub const violet_050: Color\n\nSynonyms:\nkitten/color.violet_050\nkitten/color violet_050","url":"kitten/color.html#violet_050"},{"doc":"kitten/color","title":"violet_100","content":"pub const violet_100: Color\n\nSynonyms:\nkitten/color.violet_100\nkitten/color violet_100","url":"kitten/color.html#violet_100"},{"doc":"kitten/color","title":"violet_150","content":"pub const violet_150: Color\n\nSynonyms:\nkitten/color.violet_150\nkitten/color violet_150","url":"kitten/color.html#violet_150"},{"doc":"kitten/color","title":"violet_200","content":"pub const violet_200: Color\n\nSynonyms:\nkitten/color.violet_200\nkitten/color violet_200","url":"kitten/color.html#violet_200"},{"doc":"kitten/color","title":"violet_250","content":"pub const violet_250: Color\n\nSynonyms:\nkitten/color.violet_250\nkitten/color violet_250","url":"kitten/color.html#violet_250"},{"doc":"kitten/color","title":"violet_300","content":"pub const violet_300: Color\n\nSynonyms:\nkitten/color.violet_300\nkitten/color violet_300","url":"kitten/color.html#violet_300"},{"doc":"kitten/color","title":"violet_350","content":"pub const violet_350: Color\n\nSynonyms:\nkitten/color.violet_350\nkitten/color violet_350","url":"kitten/color.html#violet_350"},{"doc":"kitten/color","title":"violet_400","content":"pub const violet_400: Color\n\nSynonyms:\nkitten/color.violet_400\nkitten/color violet_400","url":"kitten/color.html#violet_400"},{"doc":"kitten/color","title":"violet_450","content":"pub const violet_450: Color\n\nSynonyms:\nkitten/color.violet_450\nkitten/color violet_450","url":"kitten/color.html#violet_450"},{"doc":"kitten/color","title":"violet_500","content":"pub const violet_500: Color\n\nSynonyms:\nkitten/color.violet_500\nkitten/color violet_500","url":"kitten/color.html#violet_500"},{"doc":"kitten/color","title":"violet_550","content":"pub const violet_550: Color\n\nSynonyms:\nkitten/color.violet_550\nkitten/color violet_550","url":"kitten/color.html#violet_550"},{"doc":"kitten/color","title":"violet_600","content":"pub const violet_600: Color\n\nSynonyms:\nkitten/color.violet_600\nkitten/color violet_600","url":"kitten/color.html#violet_600"},{"doc":"kitten/color","title":"violet_650","content":"pub const violet_650: Color\n\nSynonyms:\nkitten/color.violet_650\nkitten/color violet_650","url":"kitten/color.html#violet_650"},{"doc":"kitten/color","title":"violet_700","content":"pub const violet_700: Color\n\nSynonyms:\nkitten/color.violet_700\nkitten/color violet_700","url":"kitten/color.html#violet_700"},{"doc":"kitten/color","title":"violet_750","content":"pub const violet_750: Color\n\nSynonyms:\nkitten/color.violet_750\nkitten/color violet_750","url":"kitten/color.html#violet_750"},{"doc":"kitten/color","title":"violet_800","content":"pub const violet_800: Color\n\nSynonyms:\nkitten/color.violet_800\nkitten/color violet_800","url":"kitten/color.html#violet_800"},{"doc":"kitten/color","title":"violet_850","content":"pub const violet_850: Color\n\nSynonyms:\nkitten/color.violet_850\nkitten/color violet_850","url":"kitten/color.html#violet_850"},{"doc":"kitten/color","title":"violet_900","content":"pub const violet_900: Color\n\nSynonyms:\nkitten/color.violet_900\nkitten/color violet_900","url":"kitten/color.html#violet_900"},{"doc":"kitten/color","title":"violet_950","content":"pub const violet_950: Color\n\nSynonyms:\nkitten/color.violet_950\nkitten/color violet_950","url":"kitten/color.html#violet_950"},{"doc":"kitten/color","title":"white","content":"pub const white: Color\n\nSynonyms:\nkitten/color.white\nkitten/color white","url":"kitten/color.html#white"},{"doc":"kitten/color","title":"yellow","content":"pub const yellow: Color\n\nSynonyms:\nkitten/color.yellow\nkitten/color yellow","url":"kitten/color.html#yellow"},{"doc":"kitten/color","title":"yellow_050","content":"pub const yellow_050: Color\n\nSynonyms:\nkitten/color.yellow_050\nkitten/color yellow_050","url":"kitten/color.html#yellow_050"},{"doc":"kitten/color","title":"yellow_100","content":"pub const yellow_100: Color\n\nSynonyms:\nkitten/color.yellow_100\nkitten/color yellow_100","url":"kitten/color.html#yellow_100"},{"doc":"kitten/color","title":"yellow_150","content":"pub const yellow_150: Color\n\nSynonyms:\nkitten/color.yellow_150\nkitten/color yellow_150","url":"kitten/color.html#yellow_150"},{"doc":"kitten/color","title":"yellow_200","content":"pub const yellow_200: Color\n\nSynonyms:\nkitten/color.yellow_200\nkitten/color yellow_200","url":"kitten/color.html#yellow_200"},{"doc":"kitten/color","title":"yellow_250","content":"pub const yellow_250: Color\n\nSynonyms:\nkitten/color.yellow_250\nkitten/color yellow_250","url":"kitten/color.html#yellow_250"},{"doc":"kitten/color","title":"yellow_300","content":"pub const yellow_300: Color\n\nSynonyms:\nkitten/color.yellow_300\nkitten/color yellow_300","url":"kitten/color.html#yellow_300"},{"doc":"kitten/color","title":"yellow_350","content":"pub const yellow_350: Color\n\nSynonyms:\nkitten/color.yellow_350\nkitten/color yellow_350","url":"kitten/color.html#yellow_350"},{"doc":"kitten/color","title":"yellow_400","content":"pub const yellow_400: Color\n\nSynonyms:\nkitten/color.yellow_400\nkitten/color yellow_400","url":"kitten/color.html#yellow_400"},{"doc":"kitten/color","title":"yellow_450","content":"pub const yellow_450: Color\n\nSynonyms:\nkitten/color.yellow_450\nkitten/color yellow_450","url":"kitten/color.html#yellow_450"},{"doc":"kitten/color","title":"yellow_500","content":"pub const yellow_500: Color\n\nSynonyms:\nkitten/color.yellow_500\nkitten/color yellow_500","url":"kitten/color.html#yellow_500"},{"doc":"kitten/color","title":"yellow_550","content":"pub const yellow_550: Color\n\nSynonyms:\nkitten/color.yellow_550\nkitten/color yellow_550","url":"kitten/color.html#yellow_550"},{"doc":"kitten/color","title":"yellow_600","content":"pub const yellow_600: Color\n\nSynonyms:\nkitten/color.yellow_600\nkitten/color yellow_600","url":"kitten/color.html#yellow_600"},{"doc":"kitten/color","title":"yellow_650","content":"pub const yellow_650: Color\n\nSynonyms:\nkitten/color.yellow_650\nkitten/color yellow_650","url":"kitten/color.html#yellow_650"},{"doc":"kitten/color","title":"yellow_700","content":"pub const yellow_700: Color\n\nSynonyms:\nkitten/color.yellow_700\nkitten/color yellow_700","url":"kitten/color.html#yellow_700"},{"doc":"kitten/color","title":"yellow_750","content":"pub const yellow_750: Color\n\nSynonyms:\nkitten/color.yellow_750\nkitten/color yellow_750","url":"kitten/color.html#yellow_750"},{"doc":"kitten/color","title":"yellow_800","content":"pub const yellow_800: Color\n\nSynonyms:\nkitten/color.yellow_800\nkitten/color yellow_800","url":"kitten/color.html#yellow_800"},{"doc":"kitten/color","title":"yellow_850","content":"pub const yellow_850: Color\n\nSynonyms:\nkitten/color.yellow_850\nkitten/color yellow_850","url":"kitten/color.html#yellow_850"},{"doc":"kitten/color","title":"yellow_900","content":"pub const yellow_900: Color\n\nSynonyms:\nkitten/color.yellow_900\nkitten/color yellow_900","url":"kitten/color.html#yellow_900"},{"doc":"kitten/color","title":"yellow_950","content":"pub const yellow_950: Color\n\nSynonyms:\nkitten/color.yellow_950\nkitten/color yellow_950","url":"kitten/color.html#yellow_950"},{"doc":"kitten/color","title":"zinc","content":"pub const zinc: Color\n\nSynonyms:\nkitten/color.zinc\nkitten/color zinc","url":"kitten/color.html#zinc"},{"doc":"kitten/color","title":"zinc_050","content":"pub const zinc_050: Color\n\nSynonyms:\nkitten/color.zinc_050\nkitten/color zinc_050","url":"kitten/color.html#zinc_050"},{"doc":"kitten/color","title":"zinc_100","content":"pub const zinc_100: Color\n\nSynonyms:\nkitten/color.zinc_100\nkitten/color zinc_100","url":"kitten/color.html#zinc_100"},{"doc":"kitten/color","title":"zinc_150","content":"pub const zinc_150: Color\n\nSynonyms:\nkitten/color.zinc_150\nkitten/color zinc_150","url":"kitten/color.html#zinc_150"},{"doc":"kitten/color","title":"zinc_200","content":"pub const zinc_200: Color\n\nSynonyms:\nkitten/color.zinc_200\nkitten/color zinc_200","url":"kitten/color.html#zinc_200"},{"doc":"kitten/color","title":"zinc_250","content":"pub const zinc_250: Color\n\nSynonyms:\nkitten/color.zinc_250\nkitten/color zinc_250","url":"kitten/color.html#zinc_250"},{"doc":"kitten/color","title":"zinc_300","content":"pub const zinc_300: Color\n\nSynonyms:\nkitten/color.zinc_300\nkitten/color zinc_300","url":"kitten/color.html#zinc_300"},{"doc":"kitten/color","title":"zinc_350","content":"pub const zinc_350: Color\n\nSynonyms:\nkitten/color.zinc_350\nkitten/color zinc_350","url":"kitten/color.html#zinc_350"},{"doc":"kitten/color","title":"zinc_400","content":"pub const zinc_400: Color\n\nSynonyms:\nkitten/color.zinc_400\nkitten/color zinc_400","url":"kitten/color.html#zinc_400"},{"doc":"kitten/color","title":"zinc_450","content":"pub const zinc_450: Color\n\nSynonyms:\nkitten/color.zinc_450\nkitten/color zinc_450","url":"kitten/color.html#zinc_450"},{"doc":"kitten/color","title":"zinc_500","content":"pub const zinc_500: Color\n\nSynonyms:\nkitten/color.zinc_500\nkitten/color zinc_500","url":"kitten/color.html#zinc_500"},{"doc":"kitten/color","title":"zinc_550","content":"pub const zinc_550: Color\n\nSynonyms:\nkitten/color.zinc_550\nkitten/color zinc_550","url":"kitten/color.html#zinc_550"},{"doc":"kitten/color","title":"zinc_600","content":"pub const zinc_600: Color\n\nSynonyms:\nkitten/color.zinc_600\nkitten/color zinc_600","url":"kitten/color.html#zinc_600"},{"doc":"kitten/color","title":"zinc_650","content":"pub const zinc_650: Color\n\nSynonyms:\nkitten/color.zinc_650\nkitten/color zinc_650","url":"kitten/color.html#zinc_650"},{"doc":"kitten/color","title":"zinc_700","content":"pub const zinc_700: Color\n\nSynonyms:\nkitten/color.zinc_700\nkitten/color zinc_700","url":"kitten/color.html#zinc_700"},{"doc":"kitten/color","title":"zinc_750","content":"pub const zinc_750: Color\n\nSynonyms:\nkitten/color.zinc_750\nkitten/color zinc_750","url":"kitten/color.html#zinc_750"},{"doc":"kitten/color","title":"zinc_800","content":"pub const zinc_800: Color\n\nSynonyms:\nkitten/color.zinc_800\nkitten/color zinc_800","url":"kitten/color.html#zinc_800"},{"doc":"kitten/color","title":"zinc_850","content":"pub const zinc_850: Color\n\nSynonyms:\nkitten/color.zinc_850\nkitten/color zinc_850","url":"kitten/color.html#zinc_850"},{"doc":"kitten/color","title":"zinc_900","content":"pub const zinc_900: Color\n\nSynonyms:\nkitten/color.zinc_900\nkitten/color zinc_900","url":"kitten/color.html#zinc_900"},{"doc":"kitten/color","title":"zinc_950","content":"pub const zinc_950: Color\n\nSynonyms:\nkitten/color.zinc_950\nkitten/color zinc_950","url":"kitten/color.html#zinc_950"},{"doc":"kitten/color","title":"from_hex","content":"pub fn from_hex(hex_string: String) -&gt; Result(Color, Nil)\n Creates a `Colour` from a hex string of the form &quot;#RRGGBB&quot;\n with R, G and B values in RGB encoding and A automatically set to 1.0. \n The values must be between 0 and 255, otherwise the function fails.\n \n ### Examples:\n \n \n color.from_hex(&quot;#ED2AAC&quot;))\n // -&gt; Ok(Color(237, 42, 172, 1.0))\n \n color.from_hex(&quot;#ZZZZZZ&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\nkitten/color.from_hex\nkitten/color from_hex","url":"kitten/color.html#from_hex"},{"doc":"kitten/color","title":"from_hexa","content":"pub fn from_hexa(hex_string: String) -&gt; Result(Color, Nil)\n Creates a `Colour` from a hex string of the form &quot;#RRGGBBAA&quot; \n with R, G, and B values in RGB encoding. R, G, B and A must be \n between 0 and 255 otherwise the function fails.\n \n ### Examples:\n \n \n color.from_hexa(&quot;#ED2AACFF&quot;))\n // -&gt; Ok(Color(237, 42, 172, 1.0))\n \n color.from_hexa(&quot;#ZZZZZZZZ&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\nkitten/color.from_hexa\nkitten/color from_hexa","url":"kitten/color.html#from_hexa"},{"doc":"kitten/color","title":"from_hsl","content":"pub fn from_hsl(h: Int, s: Int, l: Int) -&gt; Result(Color, Nil)\n Creates a `Colour` from H, S and L values in HSL encoding, with A \n automatically set to 1.0. H must be between 0 and 359, and S and L\n between 0 and 100, otherwise the function fails.\n \n ### Examples:\n \n \n color.from_hsl(240, 90, 80)\n // -&gt; Ok(Color(158, 158, 250, 1.0))\n \n color.from_hsl(400, 90, 80)\n // -&gt; Error(Nil)\n \nSynonyms:\nkitten/color.from_hsl\nkitten/color from_hsl","url":"kitten/color.html#from_hsl"},{"doc":"kitten/color","title":"from_hsla","content":"pub fn from_hsla(\n  h: Int,\n  s: Int,\n  l: Int,\n  a: Float,\n) -&gt; Result(Color, Nil)\n Creates a `Colour` from H, S, L and A values in HSL encoding. \n H must be between 0 and 359, S and L between 0 and 100, and A \n between 0.0 and 1.0, otherwise the function fails.\n \n ### Examples:\n \n \n color.from_hsla(240, 90, 80, 0.8)\n // -&gt; Ok(Color(158, 158, 250, 0.8))\n \n color.from_hsla(240, 90, 80, 2.0)\n // -&gt; Error(Nil)\n \nSynonyms:\nkitten/color.from_hsla\nkitten/color from_hsla","url":"kitten/color.html#from_hsla"},{"doc":"kitten/color","title":"from_rgb","content":"pub fn from_rgb(r: Int, g: Int, b: Int) -&gt; Result(Color, Nil)\n Creates a `Colour` from R, G and B values in RGB encoding, with A \n automatically set to 1.0. The values must be between 0 and 255,\n otherwise the function fails.\n \n ### Examples:\n \n \n color.from_rgb(237, 42, 172)\n // -&gt; Ok(Color(237, 42, 172, 1.0))\n \n color.from_rgb(237, 42, 256)\n // -&gt; Error(Nil)\n \nSynonyms:\nkitten/color.from_rgb\nkitten/color from_rgb","url":"kitten/color.html#from_rgb"},{"doc":"kitten/color","title":"from_rgba","content":"pub fn from_rgba(\n  r: Int,\n  g: Int,\n  b: Int,\n  a: Float,\n) -&gt; Result(Color, Nil)\n Creates a `Colour` from R, G, B and A values in RGB encoding. \n R, G and B must be between 0 and 255 and A between 0.0 and 1.0, \n otherwise the function fails.\n \n ### Examples:\n \n \n color.from_rgba(237, 42, 172, 0.8)\n // -&gt; Ok(Color(237, 42, 172, 0.8))\n \n color.from_rgba(237, 42, 172, 2.0)\n // -&gt; Error(Nil)\n \nSynonyms:\nkitten/color.from_rgba\nkitten/color from_rgba","url":"kitten/color.html#from_rgba"},{"doc":"kitten/color","title":"get_a","content":"pub fn get_a(color: Color) -&gt; Float\n Returns the transparency (A) value of the colour.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_a\n // -&gt; 1.0\n \nSynonyms:\nkitten/color.get_a\nkitten/color get_a","url":"kitten/color.html#get_a"},{"doc":"kitten/color","title":"get_b","content":"pub fn get_b(color: Color) -&gt; Int\n Returns the B value of the colour in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_b\n // -&gt; 172\n \nSynonyms:\nkitten/color.get_b\nkitten/color get_b","url":"kitten/color.html#get_b"},{"doc":"kitten/color","title":"get_g","content":"pub fn get_g(color: Color) -&gt; Int\n Returns the G value of the colour in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_g\n // -&gt; 42\n \nSynonyms:\nkitten/color.get_g\nkitten/color get_g","url":"kitten/color.html#get_g"},{"doc":"kitten/color","title":"get_h","content":"pub fn get_h(color: Color) -&gt; Int\n Returns the H value of the colour in HSL encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_h\n // -&gt; 320\n \nSynonyms:\nkitten/color.get_h\nkitten/color get_h","url":"kitten/color.html#get_h"},{"doc":"kitten/color","title":"get_l","content":"pub fn get_l(color: Color) -&gt; Int\n Returns the L value of the colour in HSL encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_l\n // -&gt; 55\n \nSynonyms:\nkitten/color.get_l\nkitten/color get_l","url":"kitten/color.html#get_l"},{"doc":"kitten/color","title":"get_r","content":"pub fn get_r(color: Color) -&gt; Int\n Returns the R value of the colour in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_r\n // -&gt; 237\n \nSynonyms:\nkitten/color.get_r\nkitten/color get_r","url":"kitten/color.html#get_r"},{"doc":"kitten/color","title":"get_s","content":"pub fn get_s(color: Color) -&gt; Int\n Returns the S value of the colour in HSL encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.get_s\n // -&gt; 84\n \nSynonyms:\nkitten/color.get_s\nkitten/color get_s","url":"kitten/color.html#get_s"},{"doc":"kitten/color","title":"random","content":"pub fn random() -&gt; Color\n Returns a random color. The R, G and B values are picked randomly,\n but A is always set to 1.0.\n \n ### Example: \n \n \n color.random()\n // -&gt; Color(237, 42, 172, 1.0)\n \nSynonyms:\nkitten/color.random\nkitten/color random","url":"kitten/color.html#random"},{"doc":"kitten/color","title":"set_a","content":"pub fn set_a(color: Color, new_a: Float) -&gt; Result(Color, Nil)\n Sets the transparency (A) value of the colour.\n A must be between 0.0 and 1.0, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_a(0.8)\n // -&gt; Color(237, 42, 172, 0.8)\n \nSynonyms:\nkitten/color.set_a\nkitten/color set_a","url":"kitten/color.html#set_a"},{"doc":"kitten/color","title":"set_b","content":"pub fn set_b(color: Color, new_b: Int) -&gt; Result(Color, Nil)\n Sets the B value of the colour in RGB encoding.\n G must be between 0 and 255, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_g(255)\n // -&gt; Color(237, 42, 255, 1.0)\n \nSynonyms:\nkitten/color.set_b\nkitten/color set_b","url":"kitten/color.html#set_b"},{"doc":"kitten/color","title":"set_g","content":"pub fn set_g(color: Color, new_g: Int) -&gt; Result(Color, Nil)\n Sets the G value of the colour in RGB encoding.\n G must be between 0 and 255, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_g(255)\n // -&gt; Color(237, 255, 172, 1.0)\n \nSynonyms:\nkitten/color.set_g\nkitten/color set_g","url":"kitten/color.html#set_g"},{"doc":"kitten/color","title":"set_h","content":"pub fn set_h(color: Color, new_h: Int) -&gt; Result(Color, Nil)\n Sets the H value of the colour in HSL encoding.\n H must be between 0 and 359, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_h(100)\n // -&gt; Color(108, 237, 44, 1.0)\n \nSynonyms:\nkitten/color.set_h\nkitten/color set_h","url":"kitten/color.html#set_h"},{"doc":"kitten/color","title":"set_l","content":"pub fn set_l(color: Color, new_l: Int) -&gt; Result(Color, Nil)\n Sets the L value of the colour in HSL encoding.\n L must be between 0 and 100, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_l(50)\n // -&gt; Color(235, 20, 163, 1.0)\n \nSynonyms:\nkitten/color.set_l\nkitten/color set_l","url":"kitten/color.html#set_l"},{"doc":"kitten/color","title":"set_r","content":"pub fn set_r(color: Color, new_r: Int) -&gt; Result(Color, Nil)\n Sets the R value of the colour in RGB encoding. \n R must be between 0 and 255, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_r(255)\n // -&gt; Color(255, 42, 172, 1.0)\n \nSynonyms:\nkitten/color.set_r\nkitten/color set_r","url":"kitten/color.html#set_r"},{"doc":"kitten/color","title":"set_s","content":"pub fn set_s(color: Color, new_s: Int) -&gt; Result(Color, Nil)\n Sets the S value of the colour in HSL encoding.\n S must be between 0 and 100, otherwise the function fails.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.set_s(50)\n // -&gt; Color(198, 83, 159, 1.0)\n \nSynonyms:\nkitten/color.set_s\nkitten/color set_s","url":"kitten/color.html#set_s"},{"doc":"kitten/color","title":"to_hex","content":"pub fn to_hex(color: Color) -&gt; String\n Converts a `Color` to a hex string of the form &quot;#RRGGBB&quot; in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.to_hex\n // -&gt; &quot;#ED2AAC&quot;\n \nSynonyms:\nkitten/color.to_hex\nkitten/color to_hex","url":"kitten/color.html#to_hex"},{"doc":"kitten/color","title":"to_hexa","content":"pub fn to_hexa(color: Color) -&gt; String\n Converts a `Color` to a hex string of the form &quot;#RRGGBBAA&quot; in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.to_hexa\n // -&gt; &quot;#ED2AACFF&quot;\n \nSynonyms:\nkitten/color.to_hexa\nkitten/color to_hexa","url":"kitten/color.html#to_hexa"},{"doc":"kitten/color","title":"to_hsl","content":"pub fn to_hsl(color: Color) -&gt; #(Int, Int, Int)\n Converts a `Color` to its H, S and L values in HSL encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.to_hsl\n // -&gt; #(320, 84, 55)\n \nSynonyms:\nkitten/color.to_hsl\nkitten/color to_hsl","url":"kitten/color.html#to_hsl"},{"doc":"kitten/color","title":"to_hsla","content":"pub fn to_hsla(color: Color) -&gt; #(Int, Int, Int, Float)\n Converts a `Color` to its H, S, L and A values in HSL encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.to_hsla\n // -&gt; #(320, 84, 55, 1.0)\n \nSynonyms:\nkitten/color.to_hsla\nkitten/color to_hsla","url":"kitten/color.html#to_hsla"},{"doc":"kitten/color","title":"to_rgb","content":"pub fn to_rgb(color: Color) -&gt; #(Int, Int, Int)\n Converts a `Color` to its R, G and B values in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.to_rgb\n // -&gt; #(237, 42, 172)\n \nSynonyms:\nkitten/color.to_rgb\nkitten/color to_rgb","url":"kitten/color.html#to_rgb"},{"doc":"kitten/color","title":"to_rgba","content":"pub fn to_rgba(color: Color) -&gt; #(Int, Int, Int, Float)\n Converts a `Color` to its R, G, B and A values in RGB encoding.\n \n ### Example:\n \n \n color.fuchsia_450\n |&gt; color.to_rgba\n // -&gt; #(237, 42, 172, 1.0)\n \nSynonyms:\nkitten/color.to_rgba\nkitten/color to_rgba","url":"kitten/color.html#to_rgba"},{"doc":"kitten/color","title":"kitten/color","content":" This module contains functions for working with colours.\n \n For most use cases, you should be able to import a handful of the\n pre-defined colours and use them in your code. These colours are \n taken directly from [Pico CSS](https://picocss.com/docs/colors). Use\n their website to browse the colour collection online.\n \n If you need to define custom colours though, this module provides \n functions for that too. Since they are fallible, it is highly \n recommended that you use them inside your `init` function with an\n  `assert` assignment, and store the result in your model (you might\n even go as far as to define a custom `Palette` type). This way, \n you can be sure that if your game starts without errors, the colours \n are correct.\n \n ### Examples\n \n ```gleam\n // inside a view() function\n |&gt; draw.rect(Vec2(0.0, 0.0), Vec2(50.0, 50.0), color.fuchsia_450)\n \n \n type Model {\n   Model(player_pos: Vec2, palette: Palette)\n }\n \n type Palette {\n   Palette(transparent_blue: Color, bright_green: Color) \n }\n \n fn init() {\n   let assert Ok(transparent_blue) = color.blue_600 |&gt; color.set_a(0.5)\n   let assert Ok(bright_green) = color.from_hex(&quot;2EFC0A&quot;)\n   Model(\n     player_pos: Vec2(0.0, 0.0), \n     palette: Palette(transparent_blue:, bright_green:)\n   )\n }\n \n \n ```","url":"kitten/color.html"},{"doc":"kitten/math","title":"pi","content":"pub const pi: Float\n The constant pi, accurate to 10 decimal places. \nSynonyms:\nkitten/math.pi\nkitten/math pi","url":"kitten/math.html#pi"},{"doc":"kitten/math","title":"atan2","content":"pub fn atan2(y: Float, x: Float) -&gt; Float\n The arctangent function. Note that `y` is the first argument.\nSynonyms:\nkitten/math.atan2\nkitten/math atan2","url":"kitten/math.html#atan2"},{"doc":"kitten/math","title":"cos","content":"pub fn cos(x: Float) -&gt; Float\n The cosine function.\nSynonyms:\nkitten/math.cos\nkitten/math cos","url":"kitten/math.html#cos"},{"doc":"kitten/math","title":"deg_to_rad","content":"pub fn deg_to_rad(t: Float) -&gt; Float\n Converts the given angle in degrees to radians. The result is\n guaranteed to fall between 0 and 2pi.\nSynonyms:\nkitten/math.deg_to_rad\nkitten/math deg_to_rad","url":"kitten/math.html#deg_to_rad"},{"doc":"kitten/math","title":"lerp","content":"pub fn lerp(a: Float, b: Float, p: Float) -&gt; Float\n Linearly interpolates between two numbers. Think of the result as the number \n `100 * p` percent of the way between `a` and `b`.\n \n ### Example:\n \n \n math.lerp(10.0, 20.0, 0.3)\n // -&gt; 13.0\n \nSynonyms:\nkitten/math.lerp\nkitten/math lerp","url":"kitten/math.html#lerp"},{"doc":"kitten/math","title":"rad_to_deg","content":"pub fn rad_to_deg(t: Float) -&gt; Float\n Converts the given angle in radians to degrees. The result is\n guaranteed to fall between 0 and 360.\nSynonyms:\nkitten/math.rad_to_deg\nkitten/math rad_to_deg","url":"kitten/math.html#rad_to_deg"},{"doc":"kitten/math","title":"sign","content":"pub fn sign(a: Float) -&gt; Float\n Returns `1.0` for positive numbers, `-1.0` for negative numbers and `0.0` for `0.0`.\n \n ### Examples:\n \n \n math.sign(-22.8)\n // -&gt; -1.0\n \n math.sign(0.0)\n // -&gt; 0.0\n \nSynonyms:\nkitten/math.sign\nkitten/math sign","url":"kitten/math.html#sign"},{"doc":"kitten/math","title":"sin","content":"pub fn sin(x: Float) -&gt; Float\n The sine function.\nSynonyms:\nkitten/math.sin\nkitten/math sin","url":"kitten/math.html#sin"},{"doc":"kitten/math","title":"kitten/math","content":" This module specifies a few simple mathematical functions for easy access\n in game development. \n \n Honestly, I have no idea why these are not in the standard library.","url":"kitten/math.html"},{"doc":"kitten/vec2","title":"Vec2","content":"pub type Vec2 {\n  Vec2(x: Float, y: Float)\n}\n\nVec2(x: Float, y: Float)\n\n\nSynonyms:\nkitten/vec2.Vec2\nkitten/vec2 Vec2","url":"kitten/vec2.html#Vec2"},{"doc":"kitten/vec2","title":"add","content":"pub fn add(v1: Vec2, v2: Vec2) -&gt; Vec2\n Adds two vectors component-wise.\n \n ### Example:\n \n \n vec2.add(Vec2(10.0, 20.0), Vec2(5.0, -12.0))\n // -&gt; Vec2(15.0, 8.0)\n \nSynonyms:\nkitten/vec2.add\nkitten/vec2 add","url":"kitten/vec2.html#add"},{"doc":"kitten/vec2","title":"angle","content":"pub fn angle(v: Vec2) -&gt; Float\n Calculates the angle, in *radians*, \n that the given vector makes with the positive x-direction counterclockwise.\n  \n ### Example:\n \n \n vec2.angle(Vec2(1.0, 2.0))\n // -&gt; 1.107...\n \nSynonyms:\nkitten/vec2.angle\nkitten/vec2 angle","url":"kitten/vec2.html#angle"},{"doc":"kitten/vec2","title":"clamp","content":"pub fn clamp(v: Vec2, min: Vec2, max: Vec2) -&gt; Vec2\n Clamps the vector component-wise between a minimum and a maximum.\n  \n ### Examples:\n \n \n Vec2(6.0, 8.0)\n |&gt; vec2.clamp(Vec2(1.0, 1.0), Vec2(5.0, 3.0))\n // -&gt; Vec2(5.0, 3.0)\n \n Vec2(6.0, 8.0)\n |&gt; vec2.clamp(Vec2(5.0, 9.0), Vec2(10.0, 10.0))\n // -&gt; Vec2(6.0, 9.0)\n \nSynonyms:\nkitten/vec2.clamp\nkitten/vec2 clamp","url":"kitten/vec2.html#clamp"},{"doc":"kitten/vec2","title":"clamp_length","content":"pub fn clamp_length(\n  v: Vec2,\n  min_length: Float,\n  max_length: Float,\n) -&gt; Vec2\n Clamps the length of a vector between a minimum and a maximum.\n  \n ### Examples:\n \n \n vec2.clamp_length(Vec2(6.0, 8.0), 1.0, 4.0)\n // -&gt; Vec2(1.2, 1.6)\n \n vec2.clamp_length(Vec2(6.0, 8.0), 1.0, 20.0)\n // -&gt; Vec2(6.0, 8.0)\n \nSynonyms:\nkitten/vec2.clamp_length\nkitten/vec2 clamp_length","url":"kitten/vec2.html#clamp_length"},{"doc":"kitten/vec2","title":"clamp_x","content":"pub fn clamp_x(v: Vec2, min_x: Float, max_x: Float) -&gt; Vec2\n Clamps the x-component of the vector between a minimum and a maximum.\n \n ### Examples:\n \n \n vec2.clamp_x(Vec2(6.0, 8.0), 3.0, 5.0)\n // -&gt; Vec2(5.0, 8.0)\n \n vec2.clamp_x(Vec2(6.0, 8.0), 3.0, 7.0)\n // -&gt; Vec2(6.0, 8.0)\n \nSynonyms:\nkitten/vec2.clamp_x\nkitten/vec2 clamp_x","url":"kitten/vec2.html#clamp_x"},{"doc":"kitten/vec2","title":"clamp_y","content":"pub fn clamp_y(v: Vec2, min_y: Float, max_y: Float) -&gt; Vec2\n Clamps the y-component of the vector between a minimum and a maximum.\n \n ### Examples:\n \n \n vec2.clamp_y(Vec2(6.0, 8.0), 5.0, 7.0)\n // -&gt; Vec2(6.0, 7.0)\n \n vec2.clamp_y(Vec2(6.0, 8.0), 5.0, 9.0)\n // -&gt; Vec2(6.0, 8.0)\n \nSynonyms:\nkitten/vec2.clamp_y\nkitten/vec2 clamp_y","url":"kitten/vec2.html#clamp_y"},{"doc":"kitten/vec2","title":"dist","content":"pub fn dist(v1: Vec2, v2: Vec2) -&gt; Float\n Calculates the distance between the endpoints of two vectors.\n  \n ### Example:\n \n \n vec2.dist(Vec2(4.0, 3.0), Vec2(8.0, 6.0))\n // -&gt; 5.0\n \nSynonyms:\nkitten/vec2.dist\nkitten/vec2 dist","url":"kitten/vec2.html#dist"},{"doc":"kitten/vec2","title":"dot_product","content":"pub fn dot_product(v1: Vec2, v2: Vec2) -&gt; Float\n Calculates the [dot product](https://en.wikipedia.org/wiki/Dot_product) of two vectors.\n \n ### Example:\n \n \n vec2.dot_product(Vec2(10.0, 20.0), Vec2(5.0, -12.0))\n // -&gt; -190.0\n \nSynonyms:\nkitten/vec2.dot_product\nkitten/vec2 dot_product","url":"kitten/vec2.html#dot_product"},{"doc":"kitten/vec2","title":"from_tuple","content":"pub fn from_tuple(x_y: #(Float, Float)) -&gt; Vec2\n Constructs a `Vec2` from a tuple of the x and y components. \n \n Useful in function pipes, but prefer to use the actual constructor otherwise.\n \n ### Example:\n \n \n vec2.from_tuple(6.0, 8.0)\n // -&gt; Vec2(6.0, 8.0)\n \nSynonyms:\nkitten/vec2.from_tuple\nkitten/vec2 from_tuple","url":"kitten/vec2.html#from_tuple"},{"doc":"kitten/vec2","title":"get_x","content":"pub fn get_x(v: Vec2) -&gt; Float\n Extracts the x-component of the vector.\n \n Useful in function pipes, but prefer to use the `v.x` syntax otherwise.\n \n ### Example:\n \n \n vec2.get_x(Vec2(6.0, 8.0))\n // -&gt; 6.0\n \nSynonyms:\nkitten/vec2.get_x\nkitten/vec2 get_x","url":"kitten/vec2.html#get_x"},{"doc":"kitten/vec2","title":"get_y","content":"pub fn get_y(v: Vec2) -&gt; Float\n Extracts the y-component of the vector.\n \n Useful in function pipes, but prefer to use the `v.y` syntax otherwise.\n \n ### Example:\n \n \n vec2.get_y(Vec2(6.0, 8.0))\n // -&gt; 8.0\n \nSynonyms:\nkitten/vec2.get_y\nkitten/vec2 get_y","url":"kitten/vec2.html#get_y"},{"doc":"kitten/vec2","title":"id","content":"pub fn id(v: Vec2) -&gt; Vec2\n A simple identity function specific to the Vec2 type. \n \n Useful in function pipes for extra type safety and readability.\n \n ### Example:\n \n \n vec2.id(Vec2(1.0, 2.0))\n // -&gt; Vec2(1.0, 2.0)\n \nSynonyms:\nkitten/vec2.id\nkitten/vec2 id","url":"kitten/vec2.html#id"},{"doc":"kitten/vec2","title":"invert","content":"pub fn invert(v: Vec2) -&gt; Vec2\n Returns the vector with its direction flipped.\n  \n ### Example:\n \n \n vec2.invert(Vec2(1.0, 2.0))\n // -&gt; Vec2(-1.0, -2.0)\n \nSynonyms:\nkitten/vec2.invert\nkitten/vec2 invert","url":"kitten/vec2.html#invert"},{"doc":"kitten/vec2","title":"length","content":"pub fn length(v: Vec2) -&gt; Float\n Calculates the length / magnitude of a vector.\n  \n ### Example:\n \n \n vec2.length(Vec2(4.0, 3.0))\n // -&gt; 5.0\n \nSynonyms:\nkitten/vec2.length\nkitten/vec2 length","url":"kitten/vec2.html#length"},{"doc":"kitten/vec2","title":"length_squared","content":"pub fn length_squared(v: Vec2) -&gt; Float\n Calculates the length / magnitude of a vector squared. \n Useful to make length comparisons slightly cheaper computationally.\n  \n ### Example:\n \n \n vec2.length_squared(Vec2(4.0, 3.0))\n // -&gt; 25.0\n \nSynonyms:\nkitten/vec2.length_squared\nkitten/vec2 length_squared","url":"kitten/vec2.html#length_squared"},{"doc":"kitten/vec2","title":"lerp","content":"pub fn lerp(v1: Vec2, v2: Vec2, p: Float) -&gt; Vec2\n Linearly interpolates between two vectors. \n Think of the reult as the point `100 * p` percent along the line between them.\n \n ### Example:\n \n \n vec2.lerp(Vec2(10.0, 20.0), Vec2(5.0, -12.0), 0.3)\n // -&gt; Vec2(8.5, 10.4)\n \nSynonyms:\nkitten/vec2.lerp\nkitten/vec2 lerp","url":"kitten/vec2.html#lerp"},{"doc":"kitten/vec2","title":"loosely_equals","content":"pub fn loosely_equals(\n  v1: Vec2,\n  v2: Vec2,\n  precision: Float,\n) -&gt; Bool\n Checks if the two vectors are loosely equal to the specified precision,\n similar to `float.loosely_equals`. \n The comparison is made component-wise.\n  \n ### Examples:\n \n \n vec2.loosely_equals(Vec2(1.0, 2.0), Vec2(1.01, 2.01), 0.05)\n // -&gt; True\n \n vec2.loosely_equals(Vec2(1.0, 2.0), Vec2(1.01, 2.01), 0.001)\n // -&gt; False\n \nSynonyms:\nkitten/vec2.loosely_equals\nkitten/vec2 loosely_equals","url":"kitten/vec2.html#loosely_equals"},{"doc":"kitten/vec2","title":"multiply","content":"pub fn multiply(v1: Vec2, v2: Vec2) -&gt; Vec2\n Multiplies two vectors component-wise.\n \n ### Example:\n \n \n vec2.multiply(Vec2(10.0, 20.0), Vec2(5.0, -12.0))\n // -&gt; Vec2(50.0, -240.0)\n \nSynonyms:\nkitten/vec2.multiply\nkitten/vec2 multiply","url":"kitten/vec2.html#multiply"},{"doc":"kitten/vec2","title":"normalize","content":"pub fn normalize(v: Vec2) -&gt; Vec2\n Returns the normal vector (i.e. of length 1) in the same direction as the original.\n  \n ### Example:\n \n \n vec2.normalize(Vec2(6.0, 8.0))\n // -&gt; Vec2(0.6, 0.8)\n \nSynonyms:\nkitten/vec2.normalize\nkitten/vec2 normalize","url":"kitten/vec2.html#normalize"},{"doc":"kitten/vec2","title":"rotate","content":"pub fn rotate(v: Vec2, t: Float) -&gt; Vec2\n Rotates the vector through the given angle, in *radians*, counterclockwise.\n  \n ### Example:\n \n \n vec2.rotate(Vec2(1.0, 2.0), 0.4636483268)\n // -&gt; Vec2(0.0, 2.236) (approx.)\n \nSynonyms:\nkitten/vec2.rotate\nkitten/vec2 rotate","url":"kitten/vec2.html#rotate"},{"doc":"kitten/vec2","title":"rotate_left","content":"pub fn rotate_left(v: Vec2) -&gt; Vec2\n Returns the vector rotated through 90 degrees or pi/2 radians to the left.\n\n Useful in function pipes. \n  \n ### Example:\n \n \n vec2.rotate_left(Vec2(1.0, 2.0))\n // -&gt; Vec2(-2.0, 1.0)\n \nSynonyms:\nkitten/vec2.rotate_left\nkitten/vec2 rotate_left","url":"kitten/vec2.html#rotate_left"},{"doc":"kitten/vec2","title":"rotate_right","content":"pub fn rotate_right(v: Vec2) -&gt; Vec2\n Returns the vector rotated through 90 degrees or pi/2 radians to the right.\n \n Useful in function pipes. \n  \n ### Example:\n \n \n vec2.rotate_right(Vec2(1.0, 2.0))\n // -&gt; Vec2(2.0, -1.0)\n \nSynonyms:\nkitten/vec2.rotate_right\nkitten/vec2 rotate_right","url":"kitten/vec2.html#rotate_right"},{"doc":"kitten/vec2","title":"scale","content":"pub fn scale(v: Vec2, factor: Float) -&gt; Vec2\n Scales the vector by the given factor. Works for all `Float`s.\n  \n ### Example:\n \n \n vec2.scale(Vec2(4.0, 3.0), 2.0)\n // -&gt; Vec2(8.0, 6.0)\n \nSynonyms:\nkitten/vec2.scale\nkitten/vec2 scale","url":"kitten/vec2.html#scale"},{"doc":"kitten/vec2","title":"set_angle","content":"pub fn set_angle(v: Vec2, t: Float) -&gt; Vec2\n Returns the vector with the same length as the original, \n rotated through the angle `t` *radians* counterclockwise away from the positive x-direction.\n  \n ### Example:\n \n \n vec2.set_angle(Vec2(1.0, 2.0), math.pi /. 2.0)\n // -&gt; Vec2(0.0, 2.236) (approx.)\n \nSynonyms:\nkitten/vec2.set_angle\nkitten/vec2 set_angle","url":"kitten/vec2.html#set_angle"},{"doc":"kitten/vec2","title":"set_length","content":"pub fn set_length(v: Vec2, new_length: Float) -&gt; Vec2\n Returns the vector that has the same direction as the original and the specified length.\n  \n ### Example:\n \n \n vec2.set_length(Vec2(6.0, 8.0), 1.0)\n // -&gt; Vec2(0.6, 0.8)\n \nSynonyms:\nkitten/vec2.set_length\nkitten/vec2 set_length","url":"kitten/vec2.html#set_length"},{"doc":"kitten/vec2","title":"set_x","content":"pub fn set_x(v: Vec2, new_x: Float) -&gt; Vec2\n Sets the x-component of the vector.\n \n Useful in function pipes.\n \n ### Example:\n \n \n vec2.set_x(Vec2(6.0, 8.0), 3.0)\n // -&gt; Vec2(3.0, 8.0)\n \nSynonyms:\nkitten/vec2.set_x\nkitten/vec2 set_x","url":"kitten/vec2.html#set_x"},{"doc":"kitten/vec2","title":"set_y","content":"pub fn set_y(v: Vec2, new_y: Float) -&gt; Vec2\n Sets the y-component of the vector.\n \n Useful in function pipes.\n \n ### Example:\n \n \n vec2.set_y(Vec2(6.0, 8.0), 5.0)\n // -&gt; Vec2(6.0, 5.0)\n \nSynonyms:\nkitten/vec2.set_y\nkitten/vec2 set_y","url":"kitten/vec2.html#set_y"},{"doc":"kitten/vec2","title":"subtract","content":"pub fn subtract(v1: Vec2, v2: Vec2) -&gt; Vec2\n Subtracts two vectors component-wise.\n \n ### Example:\n \n \n vec2.subtract(Vec2(10.0, 20.0), Vec2(5.0, -12.0))\n // -&gt; Vec2(5.0, 32.0)\n \nSynonyms:\nkitten/vec2.subtract\nkitten/vec2 subtract","url":"kitten/vec2.html#subtract"},{"doc":"kitten/vec2","title":"to_tuple","content":"pub fn to_tuple(v: Vec2) -&gt; #(Float, Float)\n Converts a `Vec2` to a tuple of the x and y components.\n  \n Useful in function pipes.\n \n ### Example:\n \n \n vec2.to_tuple(Vec2(6.0, 8.0))\n // -&gt; #(6.0, 8.0)\n \nSynonyms:\nkitten/vec2.to_tuple\nkitten/vec2 to_tuple","url":"kitten/vec2.html#to_tuple"},{"doc":"kitten/vec2","title":"unit","content":"pub fn unit(t: Float) -&gt; Vec2\n Returns a unit vector (i.e. vector of length `1.0`) in the given direction, \n `t` *radians* from the positive x-direction counterclockwise.\n  \n ### Example:\n \n \n vec2.length_squared(Vec2(4.0, 3.0))\n // -&gt; 25.0\n \nSynonyms:\nkitten/vec2.unit\nkitten/vec2 unit","url":"kitten/vec2.html#unit"},{"doc":"kitten/vec2","title":"unit_random","content":"pub fn unit_random() -&gt; Vec2\n Returns a unit vector a random direction.\n  \n ### Example:\n \n \n vec2.unit_random()\n // -&gt; Vec2(0.6, -0.8)\n \nSynonyms:\nkitten/vec2.unit_random\nkitten/vec2 unit_random","url":"kitten/vec2.html#unit_random"},{"doc":"kitten/vec2","title":"unit_x","content":"pub fn unit_x() -&gt; Vec2\n Returns a unit vector in the positive x direction.\n \n Useful in function pipes.\n  \n ### Example:\n \n \n vec2.unit_x()\n // -&gt; Vec2(1.0, 0.0)\n \nSynonyms:\nkitten/vec2.unit_x\nkitten/vec2 unit_x","url":"kitten/vec2.html#unit_x"},{"doc":"kitten/vec2","title":"unit_y","content":"pub fn unit_y() -&gt; Vec2\n Returns a unit vector in the positive y direction.\n \n Useful in function pipes.\n  \n ### Example:\n \n \n vec2.unit_y()\n // -&gt; Vec2(0.0, 1.0)\n \nSynonyms:\nkitten/vec2.unit_y\nkitten/vec2 unit_y","url":"kitten/vec2.html#unit_y"},{"doc":"kitten/vec2","title":"kitten/vec2","content":" This module defines a simple two-dimensional vector type and some helper functions to manipulate these vectors.\n These are used throughout the engine.\n \n ### Examples: \n \n ```gleam\n let v1 = Vec2(10.0, 20.0)\n let v2 = Vec2(40.0, 60.0)\n \n vec2.add(v1, v2) \n // -&gt; Vec2(50.0, 80.0)\n \n vec2.dist(v1, v2) \n // -&gt; 50.0\n \n vec2.clamp(v1, Vec2(0.0, 0.0), Vec2(15.0, 15.0)) \n // -&gt; Vec2(10.0, 15.0)\n ```","url":"kitten/vec2.html"},{"doc":"kitten/draw","title":"Context","content":"pub type Context\n\n\nSynonyms:\nkitten/draw.Context\nkitten/draw Context","url":"kitten/draw.html#Context"},{"doc":"kitten/draw","title":"Texture","content":"pub opaque type Texture\n\n\nSynonyms:\nkitten/draw.Texture\nkitten/draw Texture","url":"kitten/draw.html#Texture"},{"doc":"kitten/draw","title":"background","content":"pub fn background(ctx: Context, color: Color) -&gt; Context\n Sets the background colour of the canvas.\n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.background(color.slate_900)\n \nSynonyms:\nkitten/draw.background\nkitten/draw background","url":"kitten/draw.html#background"},{"doc":"kitten/draw","title":"circle","content":"pub fn circle(\n  ctx: Context,\n  pos pos: Vec2,\n  r r: Float,\n  color color: Color,\n) -&gt; Context\n Draws a circle with its centre at the specified position.\n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.circle(Vec2(0.0, 0.0), 20.0, color.red)\n \nSynonyms:\nkitten/draw.circle\nkitten/draw circle","url":"kitten/draw.html#circle"},{"doc":"kitten/draw","title":"context","content":"pub fn context() -&gt; Context\n Returns the 2D context of the canvas that you initiated the engine with.\n Every `view` function should start with this.\n \n ### Example: \n \n \n fn view(model: Model) {\n   draw.context()\n   |&gt; draw.background(color.black)\n   |&gt; draw.rect(model.pos, player_size, color.red)\n   Nil\n }\n \nSynonyms:\nkitten/draw.context\nkitten/draw context","url":"kitten/draw.html#context"},{"doc":"kitten/draw","title":"create_texture","content":"pub fn create_texture(\n  img_id: Int,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n) -&gt; Result(Texture, Nil)\n Creates a new `Texture` from the following parameters: the index of the \n image that contains the texture, starting from 0, in the order of the list\n that you passed into the engine-starting function from the `canvas` module;\n the coordinates of the top-left pixel of the texture; and its size in pixels.\n \n Since this function if fallible, it is highly recommended that you use it\n as part of your `init` function with an `assert` assignment, and store it in \n your model. This way, you can be sure that if your game starts without errors,\n the texture is correct.\n \n ### Example: \n \n \n fn init() {\n   let assert Ok(player_texture) = draw.create_texture(0, 0, 0, 16, 16)\n   Model(\n     player_pos: Vec2(0.0, 0.0),\n     player_texture: player_texture\n   )\n }\n \nSynonyms:\nkitten/draw.create_texture\nkitten/draw create_texture","url":"kitten/draw.html#create_texture"},{"doc":"kitten/draw","title":"ellipse","content":"pub fn ellipse(\n  ctx: Context,\n  pos pos: Vec2,\n  r1 r1: Float,\n  r2 r2: Float,\n  tilt tilt: Float,\n  start_angle start_angle: Float,\n  end_angle end_angle: Float,\n  filled filled: Bool,\n  width width: Float,\n  color color: Color,\n) -&gt; Context\n Draws an ellipse from the specified parameters. \n \n This function is intended to give you full access to the `ellipse` API\n of the HTML canvas, but should rarely be used on its own. Prefer the \n `circle` function for simple use cases or write wrappers around this one. \n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.ellipse(\n   Vec2(0.0, 0.0), \n   50.0, \n   20.0, \n   math.pi /. 3.0, \n   0.0, \n   2.0 *. math.pi, \n   False, \n   2.0, \n   color.red\n )\n \nSynonyms:\nkitten/draw.ellipse\nkitten/draw ellipse","url":"kitten/draw.html#ellipse"},{"doc":"kitten/draw","title":"line","content":"pub fn line(\n  ctx: Context,\n  p1 p1: Vec2,\n  p2 p2: Vec2,\n  width width: Float,\n  color color: Color,\n) -&gt; Context\n Draws a straight line between two points.\n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.line(Vec2(0.0, 0.0), Vec2(0.0, 100.0), 5.0, color.black)\n \nSynonyms:\nkitten/draw.line\nkitten/draw line","url":"kitten/draw.html#line"},{"doc":"kitten/draw","title":"path","content":"pub fn path(\n  ctx: Context,\n  points points: List(Vec2),\n  width width: Float,\n  color color: Color,\n) -&gt; Context\n Draws a non-closed path between the points, from the first to the last.\n You can repeat the first point at the end to draw a closed path.\n \n This function can be used to draw custom non-filled polygons.\n \n ### Examples: \n \n \n // inside a view() function\n |&gt; draw.path([Vec2(0.0, 0.0), Vec2(100.0, 0.0), Vec2(100.0, 100.0)], 5.0, color.red)\n \n // a wrapper to draw a regular pentagon\n fn draw_pentagon(ctx: Context, pos: Vec2, r: Float, tilt: Float, width: Float, color: Color) -&gt; Context {\n   [0.0, 0.2, 0.4, 0.6, 0.8, 0.0]\n   |&gt; list.map(fn(factor) {\n     {2 *. factor *. math.pi +. tilt}\n     |&gt; vec2.unit\n     |&gt; vec2.set_length(r)\n     |&gt; vec2.add(pos)\n   })\n   |&gt; draw.path(ctx, _, width, color)\n }\n \nSynonyms:\nkitten/draw.path\nkitten/draw path","url":"kitten/draw.html#path"},{"doc":"kitten/draw","title":"polygon","content":"pub fn polygon(\n  ctx: Context,\n  points points: List(Vec2),\n  color color: Color,\n) -&gt; Context\n Draws a *filled* polygon with its vertices at the specified points.\n \n This function can be used to draw custom filled polygons.\n \n \n ### Examples: \n \n \n // inside a view() function\n |&gt; draw.polygon([Vec2(0.0, 0.0), Vec2(100.0, 0.0), Vec2(100.0, 100.0)], color.red)\n \n // a wrapper to draw a regular pentagon\n fn draw_pentagon(ctx: Context, pos: Vec2, r: Float, tilt: Float, color: Color) -&gt; Context {\n   [0.0, 0.2, 0.4, 0.6, 0.8]\n   |&gt; list.map(fn(factor) {\n     {2 *. factor *. math.pi +. tilt}\n     |&gt; vec2.unit\n     |&gt; vec2.set_length(r)\n     |&gt; vec2.add(pos)\n   })\n   |&gt; draw.polygon(ctx, _, color)\n }\n \nSynonyms:\nkitten/draw.polygon\nkitten/draw polygon","url":"kitten/draw.html#polygon"},{"doc":"kitten/draw","title":"rect","content":"pub fn rect(\n  ctx: Context,\n  pos pos: Vec2,\n  size size: Vec2,\n  color color: Color,\n) -&gt; Context\n Draws a rectangle with its *centre* at the specified position.\n \n Use the `path` and `polygon` functions to create non-filled or tilted \n rectangles and other shapes.\n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.rect(Vec2(0.0, 0.0), Vec2(50.0, 50.0), color.red)\n \nSynonyms:\nkitten/draw.rect\nkitten/draw rect","url":"kitten/draw.html#rect"},{"doc":"kitten/draw","title":"set_camera_angle","content":"pub fn set_camera_angle(\n  ctx: Context,\n  new_angle: Float,\n) -&gt; Context\n Sets the rotation of the camera in *radians*. Always call this at the start \n of your `view` function and *after* setting the camera position.\n \n ### Example: \n \n \n fn view(model: Model) {\n   draw.context()\n   |&gt; draw.set_camera_pos(Vec2(0.0, 100.0))\n   |&gt; draw.set_camera_rotation(math.pi /. 2.0)\n   |&gt; // ... rest of the function\n }\n \nSynonyms:\nkitten/draw.set_camera_angle\nkitten/draw set_camera_angle","url":"kitten/draw.html#set_camera_angle"},{"doc":"kitten/draw","title":"set_camera_pos","content":"pub fn set_camera_pos(ctx: Context, new_pos: Vec2) -&gt; Context\n Sets the position of the camera, in world coordinates. Always call this\n at the start of your `view` function and *before* setting the camera \n scale and rotation.\n \n ### Example: \n \n \n fn view(model: Model) {\n   draw.context()\n   |&gt; draw.set_camera_pos(Vec2(0.0, 100.0))\n   |&gt; // ... rest of the function\n }\n \nSynonyms:\nkitten/draw.set_camera_pos\nkitten/draw set_camera_pos","url":"kitten/draw.html#set_camera_pos"},{"doc":"kitten/draw","title":"set_camera_scale","content":"pub fn set_camera_scale(\n  ctx: Context,\n  new_scale: Float,\n) -&gt; Context\n Sets the scale of the camera. Always call this at the start of your `view`\n function and *after* setting the camera position.\n \n ### Example: \n \n \n fn view(model: Model) {\n   draw.context()\n   |&gt; draw.set_camera_pos(Vec2(0.0, 100.0))\n   |&gt; draw.set_camera_scale(2.0)\n   |&gt; // ... rest of the function\n }\n \nSynonyms:\nkitten/draw.set_camera_scale\nkitten/draw set_camera_scale","url":"kitten/draw.html#set_camera_scale"},{"doc":"kitten/draw","title":"text","content":"pub fn text(\n  ctx: Context,\n  text text: String,\n  pos pos: Vec2,\n  size size: Float,\n  weight weight: Float,\n  font font: String,\n  tilt tilt: Float,\n  color color: Color,\n) -&gt; Context\n Draws some text with its *centre* at the specified position. \n The tilt must be given in radians.\n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.text(&quot;kitten&quot;, Vec2(0.0, 0.0), 100.0, 300.0, &quot;Arial&quot;, 0.0, color.red)\n \nSynonyms:\nkitten/draw.text\nkitten/draw text","url":"kitten/draw.html#text"},{"doc":"kitten/draw","title":"texture","content":"pub fn texture(\n  ctx: Context,\n  texture texture: Texture,\n  pos pos: Vec2,\n  size size: Vec2,\n  tilt tilt: Float,\n) -&gt; Context\n Draws a `Texture` with its *centre* at the specified position. The texture\n must be created using the `create_texture` function in this module.\n The tilt must be given in radians.\n \n ### Example: \n \n \n // inside a view() function\n |&gt; draw.texture(model.player_texture, Vec2(0.0, 0.0), Vec2(50.0, 50.0), 0.0)\n \nSynonyms:\nkitten/draw.texture\nkitten/draw texture","url":"kitten/draw.html#texture"},{"doc":"kitten/draw","title":"kitten/draw","content":" This module contains functions for drawing to the canvas. It is intended\n for use in your `view` function. Every `view` function should start with \n `draw.context`; from there, you can create a function pipe to draw all of\n your objects. All positions and sizes are in world coordinates.\n \n The `Color` type and the associated functions are defined in the `color` module.\n \n ### Example: \n \n ```gleam\n fn view(model: Model) {\n   draw.context()\n   |&gt; draw.background(color.black)\n   |&gt; draw.rect(model.pos, player_size, color.red)\n   Nil\n }\n ```","url":"kitten/draw.html"},{"doc":"kitten/key","title":"Key","content":"pub type Key {\n  ANY\n  A\n  B\n  C\n  D\n  E\n  F\n  G\n  H\n  I\n  J\n  K\n  L\n  M\n  N\n  O\n  P\n  Q\n  R\n  S\n  T\n  U\n  V\n  W\n  X\n  Y\n  Z\n  Space\n  ArrowLeft\n  ArrowUp\n  ArrowRight\n  ArrowDown\n  Backspace\n  Tab\n  Enter\n  ShiftLeft\n  ShiftRight\n  ControlLeft\n  ControlRight\n  AltLeft\n  AltRight\n  Pause\n  CapsLock\n  Escape\n  PageUp\n  PageDown\n  End\n  Home\n  PrintScreen\n  Insert\n  Delete\n  Digit0\n  Digit1\n  Digit2\n  Digit3\n  Digit4\n  Digit5\n  Digit6\n  Digit7\n  Digit8\n  Digit9\n  MetaLeft\n  MetaRight\n  ContextMenu\n  Numpad0\n  Numpad1\n  Numpad2\n  Numpad3\n  Numpad4\n  Numpad5\n  Numpad6\n  Numpad7\n  Numpad8\n  Numpad9\n  NumpadMultiply\n  NumpadAdd\n  NumpadSubtract\n  NumpadDecimal\n  NumpadDivide\n  F1\n  F2\n  F3\n  F4\n  F5\n  F6\n  F7\n  F8\n  F9\n  F10\n  F11\n  F12\n  NumLock\n  ScrollLock\n  AudioVolumeMute\n  AudioVolumeDown\n  AudioVolumeUp\n  LaunchMediaPlayer\n  LaunchApplication1\n  LaunchApplication2\n  Semicolon\n  Equal\n  Comma\n  Minus\n  Period\n  Slash\n  Backquote\n  BracketLeft\n  Backslash\n  BracketRight\n  Quote\n}\n\nANY\n\n\nA\n\n\nB\n\n\nC\n\n\nD\n\n\nE\n\n\nF\n\n\nG\n\n\nH\n\n\nI\n\n\nJ\n\n\nK\n\n\nL\n\n\nM\n\n\nN\n\n\nO\n\n\nP\n\n\nQ\n\n\nR\n\n\nS\n\n\nT\n\n\nU\n\n\nV\n\n\nW\n\n\nX\n\n\nY\n\n\nZ\n\n\nSpace\n\n\nArrowLeft\n\n\nArrowUp\n\n\nArrowRight\n\n\nArrowDown\n\n\nBackspace\n\n\nTab\n\n\nEnter\n\n\nShiftLeft\n\n\nShiftRight\n\n\nControlLeft\n\n\nControlRight\n\n\nAltLeft\n\n\nAltRight\n\n\nPause\n\n\nCapsLock\n\n\nEscape\n\n\nPageUp\n\n\nPageDown\n\n\nEnd\n\n\nHome\n\n\nPrintScreen\n\n\nInsert\n\n\nDelete\n\n\nDigit0\n\n\nDigit1\n\n\nDigit2\n\n\nDigit3\n\n\nDigit4\n\n\nDigit5\n\n\nDigit6\n\n\nDigit7\n\n\nDigit8\n\n\nDigit9\n\n\nMetaLeft\n\n\nMetaRight\n\n\nContextMenu\n\n\nNumpad0\n\n\nNumpad1\n\n\nNumpad2\n\n\nNumpad3\n\n\nNumpad4\n\n\nNumpad5\n\n\nNumpad6\n\n\nNumpad7\n\n\nNumpad8\n\n\nNumpad9\n\n\nNumpadMultiply\n\n\nNumpadAdd\n\n\nNumpadSubtract\n\n\nNumpadDecimal\n\n\nNumpadDivide\n\n\nF1\n\n\nF2\n\n\nF3\n\n\nF4\n\n\nF5\n\n\nF6\n\n\nF7\n\n\nF8\n\n\nF9\n\n\nF10\n\n\nF11\n\n\nF12\n\n\nNumLock\n\n\nScrollLock\n\n\nAudioVolumeMute\n\n\nAudioVolumeDown\n\n\nAudioVolumeUp\n\n\nLaunchMediaPlayer\n\n\nLaunchApplication1\n\n\nLaunchApplication2\n\n\nSemicolon\n\n\nEqual\n\n\nComma\n\n\nMinus\n\n\nPeriod\n\n\nSlash\n\n\nBackquote\n\n\nBracketLeft\n\n\nBackslash\n\n\nBracketRight\n\n\nQuote\n\n\nSynonyms:\nkitten/key.Key\nkitten/key Key","url":"kitten/key.html#Key"},{"doc":"kitten/key","title":"is_down","content":"pub fn is_down(key: Key) -&gt; Bool\n Returns `True` if the key was pressed in the time since the last frame,\n but has not yet been released, and `False` otherwise.\nSynonyms:\nkitten/key.is_down\nkitten/key is_down","url":"kitten/key.html#is_down"},{"doc":"kitten/key","title":"was_pressed","content":"pub fn was_pressed(key: Key) -&gt; Bool\n Returns `True` if the key was pressed in the time since the last frame,\n and `False` otherwise.\nSynonyms:\nkitten/key.was_pressed\nkitten/key was_pressed","url":"kitten/key.html#was_pressed"},{"doc":"kitten/key","title":"was_released","content":"pub fn was_released(key: Key) -&gt; Bool\n Returns `True` if the key was released in the time since the last frame,\n and `False` otherwise.\nSynonyms:\nkitten/key.was_released\nkitten/key was_released","url":"kitten/key.html#was_released"},{"doc":"kitten/key","title":"kitten/key","content":" This module contains a few simple functions to work with keyboard input.\n These are intended for use inside your `update` function.\n The custom `Key` types ensures that you can only check for real keys and prevents misspellings.\n Use `key.ANY` to check if any key was pressed, released or was down during a frame.\n \n ### Example: \n \n ```gleam\n let new_pos = case key.is_down(key.A) {\n   True -&gt; pos |&gt; vec2.add(Vec2(1.0, 0.0))\n   False -&gt; pos\n }\n ```","url":"kitten/key.html"},{"doc":"kitten/mouse","title":"Button","content":"pub type Button {\n  LMB\n  MMB\n  RMB\n}\n\nLMB\n\n\nMMB\n\n\nRMB\n\n\nSynonyms:\nkitten/mouse.Button\nkitten/mouse Button","url":"kitten/mouse.html#Button"},{"doc":"kitten/mouse","title":"is_down","content":"pub fn is_down(button: Button) -&gt; Bool\n Returns `True` if the mouse button was pressed in the time since the last frame,\n but has not yet been released, and `False` otherwise.\n Unless you specifically want the player to hold the mouse down for some time, \n you might be better off using the `was_pressed` and `was_released` functions.\nSynonyms:\nkitten/mouse.is_down\nkitten/mouse is_down","url":"kitten/mouse.html#is_down"},{"doc":"kitten/mouse","title":"pos","content":"pub fn pos() -&gt; Vec2\n Returns the position of the mouse in world coordinates.\nSynonyms:\nkitten/mouse.pos\nkitten/mouse pos","url":"kitten/mouse.html#pos"},{"doc":"kitten/mouse","title":"was_pressed","content":"pub fn was_pressed(button: Button) -&gt; Bool\n Returns `True` if the mouse button was pressed in the time since the last frame,\n and `False` otherwise.\nSynonyms:\nkitten/mouse.was_pressed\nkitten/mouse was_pressed","url":"kitten/mouse.html#was_pressed"},{"doc":"kitten/mouse","title":"was_released","content":"pub fn was_released(button: Button) -&gt; Bool\n Returns `True` if the mouse button was released in the time since the last frame,\n and `False` otherwise.\nSynonyms:\nkitten/mouse.was_released\nkitten/mouse was_released","url":"kitten/mouse.html#was_released"},{"doc":"kitten/mouse","title":"kitten/mouse","content":" This module contains a few simple functions to work with mouse input.\n These are intended for use inside your `update` function.\n The custom `Button` types ensures that you can only check for real buttons and prevents misspellings.\n \n ### Example: \n \n ```gleam\n let new_pos = case mouse.was_pressed(mouse.LMB) &amp;&amp; mouse.pos().x &gt;=. 0.0 {\n   True -&gt; pos |&gt; vec2.add(Vec2(1.0, 0.0))\n   False -&gt; pos\n }\n ```","url":"kitten/mouse.html"},{"doc":"kitten/simulate","title":"apply_forces","content":"pub fn apply_forces(\n  vel vel: Vec2,\n  mass mass: Float,\n  forces forces: List(Vec2),\n) -&gt; Vec2\n Adjusts the given velocity by applying a list of forces and taking the mass and `delta_time` into account.\n Returns *only the new velocity*.\nSynonyms:\nkitten/simulate.apply_forces\nkitten/simulate apply_forces","url":"kitten/simulate.html#apply_forces"},{"doc":"kitten/simulate","title":"apply_friction","content":"pub fn apply_friction(vel vel: Vec2, f f: Float) -&gt; Vec2\n Adjusts the given velocity by reducing all of its components, taking `delta_time` \n into account. `f` must be non-negative, or the function will fail at runtime.\nSynonyms:\nkitten/simulate.apply_friction\nkitten/simulate apply_friction","url":"kitten/simulate.html#apply_friction"},{"doc":"kitten/simulate","title":"apply_gravity","content":"pub fn apply_gravity(\n  vel vel: Vec2,\n  mass mass: Float,\n  g g: Float,\n) -&gt; Vec2\n Adjusts the given velocity by reducing its vertical component, taking `delta_time` into account.\nSynonyms:\nkitten/simulate.apply_gravity\nkitten/simulate apply_gravity","url":"kitten/simulate.html#apply_gravity"},{"doc":"kitten/simulate","title":"collision","content":"pub fn collision(\n  obj1 obj1: #(Vec2, Vec2, Vec2, Float),\n  obj2 obj2: #(Vec2, Vec2, Vec2, Float),\n  e e: Float,\n  f f: Float,\n) -&gt; #(#(Vec2, Vec2), #(Vec2, Vec2))\n Resolves the collision between two rectangular objects, defined by (in order) their *centre* positions,\n sizes, velocities and masses; taking into account the elasticity and friction coefficients. Note that this \n funcion only changes the velocities of the objects and adjusts their positions to prevent an overlap, but \n does not apply any motion. Use the `move` function to do the latter.\n \n Set the mass to 0.0 to simulate an object as static.\nSynonyms:\nkitten/simulate.collision\nkitten/simulate collision","url":"kitten/simulate.html#collision"},{"doc":"kitten/simulate","title":"collisions","content":"pub fn collisions(\n  objects objects: List(#(Vec2, Vec2, Vec2, Float)),\n  e e: Float,\n  f f: Float,\n) -&gt; List(#(Vec2, Vec2))\n Resolves collisions between every pair of objects in the list, defined by (in order) their *centre* \n position, size, velocity and mass; taking into account the elasticity and friction coefficients.\n Note that this funcion only changes the velocities of the objects and adjusts their positions to \n prevent an overlap, but does not apply any motion. Use the `move` function to do the latter.\n Set the mass to 0.0 to simulate an object as static.\nSynonyms:\nkitten/simulate.collisions\nkitten/simulate collisions","url":"kitten/simulate.html#collisions"},{"doc":"kitten/simulate","title":"delta_time","content":"pub fn delta_time() -&gt; Float\n Returns the amount of time since the previous frame was rendered, scaled so that when running\n at 60 fps, this value should always be approximately `1.0`.\nSynonyms:\nkitten/simulate.delta_time\nkitten/simulate delta_time","url":"kitten/simulate.html#delta_time"},{"doc":"kitten/simulate","title":"is_intersecting","content":"pub fn is_intersecting(\n  point1 point1: Vec2,\n  point2 point2: Vec2,\n  pos pos: Vec2,\n  size size: Vec2,\n) -&gt; Bool\n Checks if the line segment connecting the two points intersects a rectangle,\n defined by its *centre* position and size. Uses a slightly unoptimised\n Liang-Barsky algorithm.\n \n ### Example:\n \n \n is_intersecting(Vec2(0.0, -100.0), Vec2(0.0, 100.0), Vec2(0.0, 0.0), Vec2(100.0, 100.0))\n // -&gt; True\n \n is_intersecting(Vec2(-100.0, -100.0), Vec2(-100.0, 100.0), Vec2(0.0, 0.0), Vec2(100.0, 100.0))\n // -&gt; False\n \nSynonyms:\nkitten/simulate.is_intersecting\nkitten/simulate is_intersecting","url":"kitten/simulate.html#is_intersecting"},{"doc":"kitten/simulate","title":"is_overlapping","content":"pub fn is_overlapping(\n  pos1 pos1: Vec2,\n  size1 size1: Vec2,\n  pos2 pos2: Vec2,\n  size2 size2: Vec2,\n) -&gt; Bool\n Checks if the two rectangles, defined by their *centres* and sizes, are overlapping.\n Sharing an edge or a corner but no inner space counts as an overlap.\n  \n \n ### Examples:\n \n \n simulate.is_overlapping(Vec2(0.0, 0.0), Vec2(10.0, 10.0), Vec2(5.0, 5.0), Vec2(10.0, 10.0))\n // -&gt; True\n \n simulate.is_overlapping(Vec2(0.0, 0.0), Vec2(10.0, 10.0), Vec2(50.0, 50.0), Vec2(10.0, 10.0))\n // -&gt; False\n \nSynonyms:\nkitten/simulate.is_overlapping\nkitten/simulate is_overlapping","url":"kitten/simulate.html#is_overlapping"},{"doc":"kitten/simulate","title":"is_within","content":"pub fn is_within(\n  point point: Vec2,\n  pos pos: Vec2,\n  size size: Vec2,\n) -&gt; Bool\n Checks if a point lies within the rectangle, defined by its *centre* and size.\n If the point lies on the edge of the rectangle, it is considered to be within it.\n \n ### Examples:\n \n \n simulate.is_within(Vec2(0.0, 0.0), Vec2(0.0, 0.0), Vec2(10.0, 10.0))\n // -&gt; True\n \n simulate.is_within(Vec2(0.0, 0.0), Vec2(50.0, 50.0), Vec2(10.0, 10.0))\n // -&gt; False\n \nSynonyms:\nkitten/simulate.is_within\nkitten/simulate is_within","url":"kitten/simulate.html#is_within"},{"doc":"kitten/simulate","title":"move","content":"pub fn move(pos pos: Vec2, vel vel: Vec2) -&gt; Vec2\n Adjusts the position of an object by adding its velocity to it. Returns *only the new position*.\n A simple alias for `vec2.add` that takes `delta_time` into account.\n \n ### Example:\n \n \n simulate.move(Vec2(0.0, 5.0), Vec2(10.0, 0.0))\n // -&gt; Vec2(10.0, 5.0) (approx.)\n \nSynonyms:\nkitten/simulate.move\nkitten/simulate move","url":"kitten/simulate.html#move"},{"doc":"kitten/simulate","title":"screen_to_world","content":"pub fn screen_to_world(pos: Vec2) -&gt; Vec2\n Converts the given position in screen coordinates to its equivalent in \n world coordinates, under the transformation specified in the `view` \n function in the *previous* frame. \n \n Screen coordinates start in the top-left corner of the canvas, with \n the x-axis pointing right and the y-axis pointing down, and have the same \n unit as world coordinates.\n \n See the `draw` module for camera-related functions that specify this \n transformation.\nSynonyms:\nkitten/simulate.screen_to_world\nkitten/simulate screen_to_world","url":"kitten/simulate.html#screen_to_world"},{"doc":"kitten/simulate","title":"world_to_screen","content":"pub fn world_to_screen(pos: Vec2) -&gt; Vec2\n Converts the given position in world coordinates to its equivalent in \n screen coordinates, under the transformation specified in the `view` \n function in the *previous* frame. \n \n Screen coordinates start in the top-left corner of the canvas, with \n the x-axis pointing right and the y-axis pointing down, and have the same \n unit as world coordinates.\n \n See the `draw` module for camera-related functions that specify this \n transformation.\nSynonyms:\nkitten/simulate.world_to_screen\nkitten/simulate world_to_screen","url":"kitten/simulate.html#world_to_screen"},{"doc":"kitten/simulate","title":"kitten/simulate","content":" This module contains functions for working with the physics system.\n Please remember that the engine cannot simply run the physics for you,\n and that you will need to write game logic specific to your game.\n Think of this module as a collection of helper functions and not a \n full physics engine.\n \n The functions in this module may be changed in the near future. ","url":"kitten/simulate.html"},{"doc":"kitten/sound","title":"Sound","content":"pub opaque type Sound\n\n\nSynonyms:\nkitten/sound.Sound\nkitten/sound Sound","url":"kitten/sound.html#Sound"},{"doc":"kitten/sound","title":"new","content":"pub fn new(id: Int) -&gt; Result(Sound, Nil)\n Creates a new `Sound` object from the sound file at the specified index in \n the `sound_sources` list that you passed in to the engine-starting function. \n Fails if the desired sound does not exist. For use in the `init` function.\nSynonyms:\nkitten/sound.new\nkitten/sound new","url":"kitten/sound.html#new"},{"doc":"kitten/sound","title":"play","content":"pub fn play(sound: Sound) -&gt; Nil\n Plays the specified sound.\nSynonyms:\nkitten/sound.play\nkitten/sound play","url":"kitten/sound.html#play"},{"doc":"kitten/sound","title":"stop","content":"pub fn stop() -&gt; Nil\n Stops any currently playing sound.\nSynonyms:\nkitten/sound.stop\nkitten/sound stop","url":"kitten/sound.html#stop"},{"doc":"kitten/sound","title":"kitten/sound","content":" This module defines functions for working with sound effects. Kitten supports two sound systems:\n - [ZzFX](https://github.com/KilledByAPixel/ZzFX) + [ZzFXM](https://github.com/keithclark/ZzFXM) \n by Frank Force and Keith Clark\n - the usual Web Audio API (so far only tested with .mp3&#39;s, but other files should work too)\n \n Once the sounds have been loaded into the engine, you can usee the same functions\n to initiate, play and stop them, regardless of original format.\n \n To load sounds into the engine, you will need to specify paths to the files containing them\n (relative to your index.html) as strings in the `sound_sources` list when starting the engine.\n ZzFX(M) sounds must be stored as `.js` files; I highly recommend that you use their websites\n ([ZzFX](https://killedbyapixel.github.io/ZzFX/), [ZzFXM](https://keithclark.github.io/ZzFXM/))\n to create the sounds and then copy the JavaScript output.\n \n To use the sounds in your game, use the `new` function in this module, passing the index\n of the desired sound file in the `sound_sources` list as the argument. The function is \n fallible and will only work if the sound file exists and was correct (although I am still \n figuring out the details). For this reason, you should only use it in your `init` function \n with an `assert` assignment, and store the result in your model. This way, you can be sure \n that if the game starts without errors, the sounds were loaded correctly.\n \n Note that due to browser security restrictions, you will need some user interaction before playing\n a sound. In my testing with Firefox, it was sufficient that the user had pressed a key or clicked \n with their mouse at any point before the sound was played.\n \n ### Example:\n \n ```gleam\n pub fn main() {\n   canvas.start_fullscreen(init, update, view, &quot;canvas&quot;, [], [&quot;jump.js&quot;, &quot;powerup.mp3&quot;])\n }\n \n fn init() {\n   let assert Ok(jump_sound) = sound.new(0)\n   let assert Ok(powerup_sound) = sound.new(1)\n   Model( \n     // ... \n     jump_sound:,\n     powerup_sound:,\n   )\n }\n \n fn update(model: Model) {\n   // ... \n   case player_has_jumped {\n     True -&gt; sound.play(model.jump_sound)\n     False -&gt; Nil\n   }\n   case player_has_powered_up {\n     True -&gt; sound.play(model.powerup_sound)\n     False -&gt; Nil\n   }\n  // ...\n }","url":"kitten/sound.html"}]);